@@ -13,16 +13,15 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Sun Jan 23 01:41:16 EST 1994 on syllog2.watson.ibm.com
+ * Creation: Sat May 14 16:36:50 GMT 1994 on mohegan
  * Author: genc
- * Version: 0.95999999999999996
+ * Version: 0.96999999999999997335
+
 
  */
-#ifdef PLOTTER
-
 #define PLOTTER_C
-
-#include "wafe.h"
+#include <wafe.h>
+#ifdef PLOTTER
 
 #include <X11/At/Axis.h>
 #include <X11/At/BarPlot.h>
@@ -46,8 +45,8 @@
  * 	const: argc-2
  */
 
-int 
-com_AtBarPlotAttachData(clientData, comInterpreter, argc, argv)
+static int 
+cmd_AtBarPlotAttachData(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -60,13 +59,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("AtBarPlotAttachData","at least ",2,argc);
+	 wafeArgcError("AtBarPlotAttachData","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 =  name2WidgetOfClass(argv[1],atBarPlotWidgetClass,"AtBarPlot")))
           {
-          convError("AtBarPlotAttachData","1",argv[1],"AtBarPlotWidget");
+          wafeConvError("AtBarPlotAttachData","1",argv[1],"AtBarPlotWidget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -79,7 +78,7 @@ char        **argv;
              {
              if (!(sscanf(*argv, "%f", &*ptr)))
                   {
-                  convError("AtBarPlotAttachData","2",*argv,"float");
+                  wafeConvError("AtBarPlotAttachData","2",*argv,"float");
                   DBUG_RETURN (TCL_ERROR);
                   }
 
@@ -87,7 +86,7 @@ char        **argv;
           }
      }
      AtBarPlotAttachData(localVar1,castXtPointer(localVar2),AtFloat,sizeof(float),1,argc-2);
-     MMreplace(MMgetAttribList(localVar1,True),WafePermStringToQuark("AtBarPlotAttachData"),(char*)localVar2,XtFree);
+     wafeMMreplace(wafeMMgetAttribList(localVar1,True),WafePermStringToQuark("AtBarPlotAttachData"),(char*)localVar2,XtFree);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -103,8 +102,8 @@ char        **argv;
  * 	const: argc-2
  */
 
-int 
-com_AtLabelAxisAttachData(clientData, comInterpreter, argc, argv)
+static int 
+cmd_AtLabelAxisAttachData(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -117,13 +116,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("AtLabelAxisAttachData","at least ",2,argc);
+	 wafeArgcError("AtLabelAxisAttachData","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 =  name2WidgetOfClass(argv[1],atLabelAxisWidgetClass,"AtLabelAxis")))
           {
-          convError("AtLabelAxisAttachData","1",argv[1],"AtLabelAxisWidget");
+          wafeConvError("AtLabelAxisAttachData","1",argv[1],"AtLabelAxisWidget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -139,7 +138,7 @@ char        **argv;
           }
      }
      AtLabelAxisAttachData(localVar1,localVar2,sizeof(String),1,argc-2);
-     MMreplace(MMgetAttribList(localVar1,True),WafePermStringToQuark("AtLabelAxisAttachData"),(char*)localVar2,XtFree);
+     wafeMMreplace(wafeMMgetAttribList(localVar1,True),WafePermStringToQuark("AtLabelAxisAttachData"),(char*)localVar2,XtFree);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -156,8 +155,8 @@ char        **argv;
  * 	const: argc-2
  */
 
-int 
-com_AtLinePlotAttachData(clientData, comInterpreter, argc, argv)
+static int 
+cmd_AtLinePlotAttachData(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -170,13 +169,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("AtLinePlotAttachData","at least ",2,argc);
+	 wafeArgcError("AtLinePlotAttachData","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 =  name2WidgetOfClass(argv[1],atLinePlotWidgetClass,"AtLinePlot")))
           {
-          convError("AtLinePlotAttachData","1",argv[1],"AtLinePlotWidget");
+          wafeConvError("AtLinePlotAttachData","1",argv[1],"AtLinePlotWidget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -189,7 +188,7 @@ char        **argv;
              {
              if (!(sscanf(*argv, "%f", &*ptr)))
                   {
-                  convError("AtLinePlotAttachData","2",*argv,"float");
+                  wafeConvError("AtLinePlotAttachData","2",*argv,"float");
                   DBUG_RETURN (TCL_ERROR);
                   }
 
@@ -197,18 +196,19 @@ char        **argv;
           }
      }
      AtLinePlotAttachData(localVar1,castXtPointer(localVar2),AtFloat,sizeof(float),1,argc-2);
-     MMreplace(MMgetAttribList(localVar1,True),WafePermStringToQuark("AtLinePlotAttachData"),(char*)localVar2,XtFree);
+     wafeMMreplace(wafeMMgetAttribList(localVar1,True),WafePermStringToQuark("AtLinePlotAttachData"),(char*)localVar2,XtFree);
 
      DBUG_RETURN (TCL_OK);
      }     
 
 
+#include <Plotter.h>
 /* 
  * void
  * AtPlotterGeneratePostscript
- *         in: char *            		       # file name
+ *         in: String            		       # file name
  *         in: (AtPlotterWidget)AtPlotterWidget   # plotter widget
- * 	in: char *            		       # title
+ * 	in: String            		       # title
  * 	in: int               		       # bounding box: x1
  * 	in: int              		       # bounding box: y1
  * 	in: int               		       # bounding box: x2
@@ -216,8 +216,8 @@ char        **argv;
  * 	in: Boolean           		       # landscape
  */
 
-int 
-com_AtPlotterGeneratePostscript(clientData, comInterpreter, argc, argv)
+static int 
+cmd_AtPlotterGeneratePostscript(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -234,7 +234,7 @@ char        **argv;
 
      if (argc != 9) 
 	 {
-	 argcError("AtPlotterGeneratePostscript","",8,argc);
+	 wafeArgcError("AtPlotterGeneratePostscript","",8,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -242,7 +242,7 @@ char        **argv;
 
      if (!(localVar2 =  name2WidgetOfClass(argv[2],atPlotterWidgetClass,"AtPlotter")))
           {
-          convError("AtPlotterGeneratePostscript","2",argv[2],"AtPlotterWidget");
+          wafeConvError("AtPlotterGeneratePostscript","2",argv[2],"AtPlotterWidget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -250,36 +250,36 @@ char        **argv;
 
      if (!(sscanf(argv[4], "%d", &localVar4)))
           {
-          convError("AtPlotterGeneratePostscript","4",argv[4],"int");
+          wafeConvError("AtPlotterGeneratePostscript","4",argv[4],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
      if (!(sscanf(argv[5], "%d", &localVar5)))
           {
-          convError("AtPlotterGeneratePostscript","5",argv[5],"int");
+          wafeConvError("AtPlotterGeneratePostscript","5",argv[5],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
      if (!(sscanf(argv[6], "%d", &localVar6)))
           {
-          convError("AtPlotterGeneratePostscript","6",argv[6],"int");
+          wafeConvError("AtPlotterGeneratePostscript","6",argv[6],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
      if (!(sscanf(argv[7], "%d", &localVar7)))
           {
-          convError("AtPlotterGeneratePostscript","7",argv[7],"int");
+          wafeConvError("AtPlotterGeneratePostscript","7",argv[7],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     if (!strcmp(argv[8], "true")) 
-         localVar8 = 1;
-     else
      if (!strcmp(argv[8], "false")) 
          localVar8 = 0;
+     else
+     if (!strcmp(argv[8], "true")) 
+         localVar8 = 1;
      else
          {
-         convError("AtPlotterGeneratePostscript","8",argv[8],"Boolean");
+         wafeConvError("AtPlotterGeneratePostscript","8",argv[8],"Boolean");
          DBUG_RETURN (TCL_ERROR);
         }
 
@@ -295,7 +295,7 @@ char        **argv;
  */
 /* yes, it is really  -*-C-*-  */
 
-void
+static void
 xyLinePlotAttachData(w,argc,argv)
 Widget    w;
 int       argc;
@@ -311,7 +311,8 @@ char    **argv;
          {
          if (!(sscanf(argv[count],"%f/%f",x,y)))
               {
-              convError("xyLinePlotAttachData","in array", argv[count],"x/y");
+              wafeConvError("xyLinePlotAttachData",
+			    "in array", argv[count],"x/y");
               return;
               }
           }
@@ -321,10 +322,12 @@ char    **argv;
 			    (XtPointer)yarray, AtFloat, sizeof(float),
 			    1,argc);
 
-     MMreplace(MMgetAttribList(w,True),WafePermStringToQuark("LinePlotXData"),
-	       (char*)xarray,XtFree);
-     MMreplace(MMgetAttribList(w,True),WafePermStringToQuark("LinePlotYData"),
-	       (char*)yarray,XtFree);
+     wafeMMreplace(wafeMMgetAttribList(w,True),
+		   WafePermStringToQuark("LinePlotXData"),
+		   (char*)xarray,XtFree);
+     wafeMMreplace(wafeMMgetAttribList(w,True),
+		   WafePermStringToQuark("LinePlotYData"),
+		   (char*)yarray,XtFree);
      }     
 
 
@@ -340,8 +343,8 @@ char    **argv;
 
  */
 
-int 
-com_AtXYLinePlotAttachData(clientData, comInterpreter, argc, argv)
+static int 
+cmd_AtXYLinePlotAttachData(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -353,13 +356,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("AtXYLinePlotAttachData","at least ",2,argc);
+	 wafeArgcError("AtXYLinePlotAttachData","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 =  name2WidgetOfClass(argv[1],atXYLinePlotWidgetClass,"AtXYLinePlot")))
           {
-          convError("AtXYLinePlotAttachData","1",argv[1],"AtXYLinePlotWidget");
+          wafeConvError("AtXYLinePlotAttachData","1",argv[1],"AtXYLinePlotWidget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -371,29 +374,28 @@ char        **argv;
 
 
 #else
-#include "wafe.h"
 #endif
 
 void
-Initialize_AtGen()
+wafeInitialize_AtGen()
 {
 #ifdef PLOTTER
- createWidgetCommand("AtAxis",atAxisWidgetClass,NULL,False);
- createWidgetCommand("AtBarPlot",atBarPlotWidgetClass,NULL,False);
- createWidgetCommand("AtLabelAxis",atLabelAxisWidgetClass,NULL,False);
- createWidgetCommand("AtLinePlot",atLinePlotWidgetClass,NULL,False);
- createWidgetCommand("AtPlotter",atPlotterWidgetClass,NULL,False);
- createWidgetCommand("AtTextPlot",atTextPlotWidgetClass,NULL,False);
- createWidgetCommand("AtXYAxis",atXYAxisWidgetClass,NULL,False);
- createWidgetCommand("AtXYLinePlot",atXYLinePlotWidgetClass,NULL,False);
+ wafeCreateWidgetCommand("AtAxis",atAxisWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtBarPlot",atBarPlotWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtLabelAxis",atLabelAxisWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtLinePlot",atLinePlotWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtPlotter",atPlotterWidgetClass,NULL,False);
+ wafeCreateWidgetCommand("AtTextPlot",atTextPlotWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtXYAxis",atXYAxisWidgetClass,WafeDontManage,False);
+ wafeCreateWidgetCommand("AtXYLinePlot",atXYLinePlotWidgetClass,WafeDontManage,False);
 #ifdef PLOTTER
  strcat(wafePackages,"PLOTTER ");
 #endif
- Tcl_CreateCommand(wafeInterpreter, "AtBarPlotAttachData", com_AtBarPlotAttachData, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "AtLabelAxisAttachData", com_AtLabelAxisAttachData, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "AtLinePlotAttachData", com_AtLinePlotAttachData, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "AtPlotterGeneratePostscript", com_AtPlotterGeneratePostscript, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "AtXYLinePlotAttachData", com_AtXYLinePlotAttachData, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "AtBarPlotAttachData", cmd_AtBarPlotAttachData, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "AtLabelAxisAttachData", cmd_AtLabelAxisAttachData, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "AtLinePlotAttachData", cmd_AtLinePlotAttachData, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "AtPlotterGeneratePostscript", cmd_AtPlotterGeneratePostscript, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "AtXYLinePlotAttachData", cmd_AtXYLinePlotAttachData, NULL, NULL);
 
 #else
 #endif
