@@ -13,18 +13,18 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Fri Dec  3 21:44:46 EST 1993 on syllog2.watson.ibm.com
+ * Creation: Mon May  2 23:29:09 EDT 1994 on syllog2.watson.ibm.com
  * Author: genc
  * Version: 0.95999999999999996
 
+
  */
 #define MISC
 
+#define MISC_C
+#include <wafe.h>
 #ifdef MISC
 
-#define MISC_C
-
-#include "wafe.h"
 #include <time.h>
 #define ref(a) &(a)
 
@@ -32,7 +32,6 @@
  * ******* begin required file <misc.inc> *******
  */
 /* das ist ein -*- C -*- Programm */
-/*#include "tclInt.h"*/
 
 /* this definition is from tclInt.h 
  * the first FOUR entries match EXACT the Interp struct from 
@@ -61,38 +60,70 @@ typedef struct Interp {
                                  * by strings; values have type (Command *). */
     } Interp;
 
-int
-alias(newCmd,oldCmd)
-char *newCmd;
-char *oldCmd;
+extern void wafeRegisterCmd(
+#if NeedFunctionPrototypes
+    int, String
+#endif
+);
+
+extern void wafeUnregisterCmd(
+#if NeedFunctionPrototypes
+    int
+#endif
+);
+
+extern void wafeSetCommunicationVariableCmd(
+#if NeedFunctionPrototypes
+    String, int, String
+#endif
+);
+
+extern XtInputId wafeAddInputCmd(
+#if NeedFunctionPrototypes
+    int, XtPointer, String, String
+#endif
+);
+
+extern void wafeRemoveInputCmd(
+#if NeedFunctionPrototypes
+    XtInputId 
+#endif
+);
+
+
+
+static int
+alias(newCmdName,oldCmdName)
+String newCmdName;
+String oldCmdName;
     {
     XtPointer cmdPtr;
     Interp *iPtr = (Interp *) wafeInterpreter;
     Tcl_HashEntry *hPtr;
     int new;    
 
-    if ((hPtr = Tcl_FindHashEntry(&iPtr->commandTable, newCmd)) != NULL)
+    if ((hPtr = Tcl_FindHashEntry(&iPtr->commandTable, newCmdName)) != NULL)
 	{
 	fprintf(stderr,
 		"Wafe(alias): can't alias to '%s': command already exists\n",
-		newCmd);
-        /* Tcl_AppendResult(wafeInterpreter, "can't alias to \"", newCmd,
+		newCmdName);
+        /* Tcl_AppendResult(wafeInterpreter, "can't alias to \"", newCmdName,
                 "\": command already exists", (char *) NULL); */
         return 0;
 	}
     
-    if ((hPtr = Tcl_FindHashEntry(&iPtr->commandTable, oldCmd)) == NULL)
+    if ((hPtr = Tcl_FindHashEntry(&iPtr->commandTable, oldCmdName)) == NULL)
 	{
 	fprintf(stderr,
 		"Wafe(alias): can't alias '%s': command doesn't exist\n",
-		oldCmd);
-        /* Tcl_AppendResult(wafeInterpreter, "can't alias \"", oldCmd,
+		oldCmdName);
+        /* Tcl_AppendResult(wafeInterpreter, "can't alias \"", oldCmdName,
                 "\":  command doesn't exist", (char *) NULL); */
         return 0;
 	}
 
     cmdPtr = (XtPointer) Tcl_GetHashValue(hPtr);
-    hPtr = Tcl_CreateHashEntry(&iPtr->commandTable, newCmd, &new);
+    hPtr = Tcl_CreateHashEntry(&iPtr->commandTable, newCmdName, &new);
     Tcl_SetHashValue(hPtr, cmdPtr);
     return 1;
 }
@@ -106,8 +137,8 @@ char *oldCmd;
  * 	in: ref(time_t)			# clock value
  */
 
-int 
-com_ctime(clientData, comInterpreter, argc, argv)
+static int 
+cmd_ctime(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -120,13 +151,13 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("ctime","",1,argc);
+	 wafeArgcError("ctime","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(sscanf(argv[1], "%ld", &localVar1)))
           {
-          convError("ctime","1",argv[1],"time_t");
+          wafeConvError("ctime","1",argv[1],"time_t");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -149,8 +180,8 @@ char        **argv;
  * 	post: write(wafeToClient, "\n",1);
  */
 
-int 
-com_echo(clientData, comInterpreter, argc, argv)
+static int 
+cmd_echo(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -163,7 +194,7 @@ char        **argv;
 
      if (argc < 2) 
 	 {
-	 argcError("echo","at least ",1,argc);
+	 wafeArgcError("echo","at least ",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -186,8 +217,8 @@ char        **argv;
  * 	const:				# None
  */
 
-int 
-com_getChannel(clientData, comInterpreter, argc, argv)
+static int 
+cmd_getChannel(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -200,7 +231,7 @@ char        **argv;
 
      if (argc != 1) 
 	 {
-	 argcError("getChannel","",0,argc);
+	 wafeArgcError("getChannel","",0,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -224,8 +255,8 @@ char        **argv;
  * 	post: exit(0);
  */
 
-int 
-com_quit(clientData, comInterpreter, argc, argv)
+static int 
+cmd_quit(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -236,7 +267,7 @@ char        **argv;
 
      if (argc != 1) 
 	 {
-	 argcError("quit","",0,argc);
+	 wafeArgcError("quit","",0,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -251,12 +282,13 @@ char        **argv;
 /* 
  * void 
  * kill
- *     in: int                      	# process id
- *     in: (int)signalType         	# signalType
+ *     pre: localVar2 -= HANDLERMAX;
+ *     in: int                      		# process id
+ *     in: (int) signalType	         	# signalType
  */
 
-int 
-com_kill(clientData, comInterpreter, argc, argv)
+static int 
+cmd_kill(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -269,13 +301,13 @@ char        **argv;
 
      if (argc != 3) 
 	 {
-	 argcError("kill","",2,argc);
+	 wafeArgcError("kill","",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(sscanf(argv[1], "%d", &localVar1)))
           {
-          convError("kill","1",argv[1],"int");
+          wafeConvError("kill","1",argv[1],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -301,11 +333,12 @@ char        **argv;
          localVar2 = HANDLERMAX+SIGUSR2;
      else
          {
-         convError("kill","2",argv[2],"signalType");
+         wafeConvError("kill","2",argv[2],"signalType");
          DBUG_RETURN (TCL_ERROR);
         }
 
 
+     localVar2 -= HANDLERMAX;
      kill(localVar1,localVar2);
 
      DBUG_RETURN (TCL_OK);
@@ -314,13 +347,13 @@ char        **argv;
 
 /* 
  * void
- * doregister vulgo register
+ * wafeRegisterCmd vulgo register
  * 	in: (int)handlerType	# stdin | stdout | stderr | xioerr | ..signal..
  * 	in: String		# tcl-command
  */
 
-int 
-com_register(clientData, comInterpreter, argc, argv)
+static int 
+cmd_register(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -332,7 +365,7 @@ char        **argv;
 
      if (argc != 3) 
 	 {
-	 argcError("register","",2,argc);
+	 wafeArgcError("register","",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -373,14 +406,14 @@ char        **argv;
          localVar1 = HANDLERMAX+SIGUSR2;
      else
          {
-         convError("register","1",argv[1],"handlerType");
+         wafeConvError("register","1",argv[1],"handlerType");
          DBUG_RETURN (TCL_ERROR);
         }
 
 
     /* no need to assign  << localVar2 = argv[2] >>  */ 
 
-     doregister(localVar1,argv[2]);
+     wafeRegisterCmd(localVar1,argv[2]);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -388,14 +421,14 @@ char        **argv;
 
 /* 
  * void
- * setCommunicationVariable
+ * wafeSetCommunicationVariableCmd vulgo setCommunicationVariable
  * 	in: XtNewString(String)		# variable name
  * 	in: int				# length
  * 	in: XtNewString(String)		# tcl command to be executed
  */
 
-int 
-com_setCommunicationVariable(clientData, comInterpreter, argc, argv)
+static int 
+cmd_setCommunicationVariable(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -407,7 +440,7 @@ char        **argv;
 
      if (argc != 4) 
 	 {
-	 argcError("setCommunicationVariable","",3,argc);
+	 wafeArgcError("setCommunicationVariable","",3,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -415,13 +448,13 @@ char        **argv;
 
      if (!(sscanf(argv[2], "%d", &localVar2)))
           {
-          convError("setCommunicationVariable","2",argv[2],"int");
+          wafeConvError("setCommunicationVariable","2",argv[2],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
     /* no need to assign  << localVar3 = argv[3] >>  */ 
 
-     setCommunicationVariable(XtNewString(argv[1]),localVar2,XtNewString(argv[3]));
+     wafeSetCommunicationVariableCmd(XtNewString(argv[1]),localVar2,XtNewString(argv[3]));
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -429,12 +462,12 @@ char        **argv;
 
 /* 
  * void
- * unregister
+ * wafeUnregisterCmd vulgo unregister
  * 	in: (int)handlerType		# stdin | stdout | stderr | xioerr
  */
 
-int 
-com_unregister(clientData, comInterpreter, argc, argv)
+static int 
+cmd_unregister(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -446,7 +479,7 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("unregister","",1,argc);
+	 wafeArgcError("unregister","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -487,12 +520,12 @@ char        **argv;
          localVar1 = HANDLERMAX+SIGUSR2;
      else
          {
-         convError("unregister","1",argv[1],"handlerType");
+         wafeConvError("unregister","1",argv[1],"handlerType");
          DBUG_RETURN (TCL_ERROR);
         }
 
 
-     unregister(localVar1);
+     wafeUnregisterCmd(localVar1);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -500,15 +533,15 @@ char        **argv;
 
 /* 
  * XtInputId
- * addInput 
+ * wafeAddInputCmd vulgo addInput 
  * 	in: int				# fileno
  * 	in: (XtPointer)SourceInputMask	# read | write | except | none
  * 	in: String    			# TclVariable 
  * 	in: String 			# TclCommand
  */
 
-int 
-com_addInput(clientData, comInterpreter, argc, argv)
+static int 
+cmd_addInput(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -523,13 +556,13 @@ char        **argv;
 
      if (argc != 5) 
 	 {
-	 argcError("addInput","",4,argc);
+	 wafeArgcError("addInput","",4,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(sscanf(argv[1], "%d", &localVar1)))
           {
-          convError("addInput","1",argv[1],"int");
+          wafeConvError("addInput","1",argv[1],"int");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -546,7 +579,7 @@ char        **argv;
          localVar2 = (XtPointer)XtInputNoneMask;
      else
          {
-         convError("addInput","2",argv[2],"SourceInputMask");
+         wafeConvError("addInput","2",argv[2],"SourceInputMask");
          DBUG_RETURN (TCL_ERROR);
         }
 
@@ -555,7 +588,7 @@ char        **argv;
 
     /* no need to assign  << localVar4 = argv[4] >>  */ 
 
-     returnVar = addInput(localVar1,localVar2,argv[3],argv[4]);
+     returnVar = wafeAddInputCmd(localVar1,localVar2,argv[3],argv[4]);
 
      sprintf(conversionBuffer, "%lu", returnVar);
      Tcl_SetResult(comInterpreter, conversionBuffer, TCL_VOLATILE);
@@ -566,12 +599,12 @@ char        **argv;
 
 /* 
  * void
- * removeInput
+ * wafeRemoveInputCmd vulgo removeInput
  * 	in: XtInputId			# input id
  */
 
-int 
-com_removeInput(clientData, comInterpreter, argc, argv)
+static int 
+cmd_removeInput(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -583,17 +616,17 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("removeInput","",1,argc);
+	 wafeArgcError("removeInput","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(sscanf(argv[1], "%lu", &localVar1)))
           {
-          convError("removeInput","1",argv[1],"XtInputId");
+          wafeConvError("removeInput","1",argv[1],"XtInputId");
           DBUG_RETURN (TCL_ERROR);
           }
 
-     removeInput(localVar1);
+     wafeRemoveInputCmd(localVar1);
 
      DBUG_RETURN (TCL_OK);
      }     
@@ -610,8 +643,8 @@ char        **argv;
  * 	post: }
  */
 
-int 
-com_fileno(clientData, comInterpreter, argc, argv)
+static int 
+cmd_fileno(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -625,7 +658,7 @@ char        **argv;
 
      if (argc != 3) 
 	 {
-	 argcError("fileno","",2,argc);
+	 wafeArgcError("fileno","",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -644,7 +677,7 @@ char        **argv;
          localVar2 = 1;
      else
          {
-         convError("fileno","2",argv[2],"FileNoReadWrite");
+         wafeConvError("fileno","2",argv[2],"FileNoReadWrite");
          DBUG_RETURN (TCL_ERROR);
         }
 
@@ -667,8 +700,8 @@ char        **argv;
  * 	in: String			# old command
  */
 
-int 
-com_alias(clientData, comInterpreter, argc, argv)
+static int 
+cmd_alias(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -681,7 +714,7 @@ char        **argv;
 
      if (argc != 3) 
 	 {
-	 argcError("alias","",2,argc);
+	 wafeArgcError("alias","",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -699,25 +732,24 @@ char        **argv;
 
 
 #else
-#include "wafe.h"
 #endif
 
 void
-Initialize_MiscGen()
+wafeInitialize_MiscGen()
 {
 #ifdef MISC
- Tcl_CreateCommand(wafeInterpreter, "ctime", com_ctime, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "echo", com_echo, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "getChannel", com_getChannel, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "quit", com_quit, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "kill", com_kill, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "register", com_register, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "setCommunicationVariable", com_setCommunicationVariable, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "unregister", com_unregister, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "addInput", com_addInput, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "removeInput", com_removeInput, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "fileno", com_fileno, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "alias", com_alias, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "ctime", cmd_ctime, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "echo", cmd_echo, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "getChannel", cmd_getChannel, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "quit", cmd_quit, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "kill", cmd_kill, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "register", cmd_register, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "setCommunicationVariable", cmd_setCommunicationVariable, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "unregister", cmd_unregister, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "addInput", cmd_addInput, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "removeInput", cmd_removeInput, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "fileno", cmd_fileno, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "alias", cmd_alias, NULL, NULL);
 
 #else
 #endif
