@@ -13,17 +13,16 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Sun Jan 23 03:51:12 EST 1994 on syllog2.watson.ibm.com
+ * Creation: Mon May  2 23:29:35 EDT 1994 on syllog2.watson.ibm.com
  * Author: genc
  * Version: 0.95999999999999996
 
+
  */
+#define MOTIF12_C
+#include <wafe.h>
 #ifdef MOTIF12
 
-#define MOTIF12_C
-
-#include "wafe.h"
-#include <Xm/Xm.h>
 #include <X11/Shell.h>
 
 /* 
@@ -36,13 +35,13 @@
 
 #include <Xm/DragDrop.h>
 
-extern XmString stringToXmString(
+extern XmString wafeCvtStringToXmString(
 #if NeedFunctionPrototypes
     char *
 #endif
 );
 
-extern char * xmString2String(
+extern char * wafeCvtXmString2String(
 #if NeedFunctionPrototypes
     char *, XmString
 #endif
@@ -68,7 +67,7 @@ static Widget currentDragContext;
 	    return True;					\
 	}
 
-void
+static void
 callbackProc(w, clientData, callData)
 Widget w;
 XtPointer clientData;
@@ -81,16 +80,16 @@ XtPointer callData;
 	    (XmDropProcCallbackStruct *)callData;
 	char *cmd;
 	/*fprintf(stderr,"dropProc: getting attriblist of <%s>\n",XtName(w));*/
-	cmd = (char *)MMgetValue(MMgetAttribList(w,True), qdropProc);
+	cmd = (char *)wafeMMgetValue(wafeMMgetAttribList(w,True), qdropProc);
 	/*fprintf(stderr,"in callbackProc, dropProc, widget = %p <%s> cmd=<%s>\n",
 		w,XtName(w),cmd+sizeof(XrmQuark));
          */
-	execCallbackProc(drop_cbs->dragContext, (XtPointer)cmd, callData);
+	wafeExecCallbackProc(drop_cbs->dragContext, (XtPointer)cmd, callData);
 	}
     }
 
 
-Boolean
+static Boolean
 convertSelectionIncrProc(w, selection, target, type, value, length, format,
 			 max_length, client_data, request_id)
 Widget        w;
@@ -120,10 +119,11 @@ XtRequestId   *request_id;
 	   call it and provide the target as callData; this is necessary
 	   for the DELETE target in DROP_MOVE command
 	 */
-	if ((cmd = (char *)MMgetValue(MMgetAttribList(w,True), qconvertProc)))
+	if ((cmd = (char *)wafeMMgetValue(wafeMMgetAttribList(w,True), 
+					  qconvertProc)))
 	    {
 	    targetName = XGetAtomName(dpy,*target);
-	    execCallbackProc(w, (XtPointer)cmd, targetName);
+	    wafeExecCallbackProc(w, (XtPointer)cmd, targetName);
 	    }
 	    
 	if (*target == COMPOUND_TEXT)
@@ -140,7 +140,7 @@ XtRequestId   *request_id;
 		return False;
 		}
 
-	    t = stringToXmString(*cd);
+	    t = wafeCvtStringToXmString(*cd);
 	    /* it is wierd that the returned compound text is of type
                char* since - as it looks to me - CT can have inbedded
                nulls, which will cause truncations on strlen etc 
@@ -202,7 +202,7 @@ XtRequestId   *request_id;
     return result;
     }
 
-void
+static void
 selectionCallbackProc (w, closure, selection, type, value, length, format)
 Widget          w;
 XtPointer       closure;
@@ -227,7 +227,8 @@ int*            format;
 	if (! *selection == XmInternAtom(dpy, "_MOTIF_DROP", False))
 	    return;   /* to avoid surprises... */
 
-	if (!(cmd = (char *)MMgetValue(MMgetAttribList(w,True), qtransferProc)))
+	if (!(cmd = (char *)wafeMMgetValue(wafeMMgetAttribList(w,True), 
+					   qtransferProc)))
 	    {
 	    fprintf(stderr,"Wafe(%s): no transferProc registered\n","selectionCallbackProc");
 	    return;
@@ -244,12 +245,12 @@ int*            format;
 	if (*type == COMPOUND_TEXT)
 	    {
 	    XmString t = XmCvtCTToXmString(value);
-	    dtCbs.value = xmString2String(NULL,t);
+	    dtCbs.value = wafeCvtXmString2String(NULL,t);
 /*
 	    fprintf(stderr,"+ in callbackProc, transferProc, widget = %p <%s> cmd=<%s>, <%s> <%s>\n",
 		    w,XtName(w),cmd+sizeof(XrmQuark),dtCbs.value,value);
  */
-	    execCallbackProc(w, (XtPointer)cmd, &dtCbs);
+	    wafeExecCallbackProc(w, (XtPointer)cmd, &dtCbs);
 	    XtFree(dtCbs.value);
 	    XmStringFree(t);
 	    }
@@ -292,7 +293,7 @@ XtPointer *converter_data;
     *(XrmQuark *)charp = wafeCurrentAttrib;
     strcpy((char *)charp + sizeof(XrmQuark), (char *)fromVal->addr);
 
-    MMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
+    wafeMMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
 	      (char *)charp, XtFree);
     Done(XtCallbackProc, &callbackProc);
     }
@@ -368,7 +369,7 @@ XtPointer *converter_data;
     *(XrmQuark *)charp = wafeCurrentAttrib;
     strcpy((char *)charp + sizeof(XrmQuark), (char *)fromVal->addr);
 
-    MMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
+    wafeMMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
 	      (char *)charp, XtFree);
     return True;
     }
@@ -389,12 +390,12 @@ XtPointer *converter_data;
     *(XrmQuark *)charp = wafeCurrentAttrib;
     strcpy((char *)charp + sizeof(XrmQuark), (char *)fromVal->addr);
 
-    MMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
+    wafeMMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
 	      (char *)charp, XtFree);
     Done(XtCallbackProc, &selectionCallbackProc);
     }
 
-XmDropTransferEntryRec *
+static XmDropTransferEntryRec *
 string2transferEntryRec(string,dpy)
 char * string;
 Display *dpy;
@@ -428,7 +429,7 @@ Display *dpy;
 	    return NULL;
 	    }
 	entries->target = XInternAtom(dpy, innerArgv[0], False);
-	entries->client_data = cvtName2Widget(innerArgv[1],True,NULL,NULL);
+	entries->client_data = wafeCvtName2Widget(innerArgv[1],True,NULL,NULL);
 	entries++;
 	XtFree((char *)innerArgv);
 	}
@@ -451,20 +452,20 @@ XtPointer *converter_data;
     if (!(dropRecs = string2transferEntryRec(fromVal->addr,dpy)))
 	return False;
     
-    MMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
+    wafeMMreplace(wafeCurrentAttribList, wafeCurrentAttrib,
 	      (char *)dropRecs, XtFree);
     Done(XmDropTransferEntryRec*, dropRecs);
     }
 
 
 
-void
+static void
 CBfreeAttribs(w, client_data, call_data)
 Widget w;
 caddr_t client_data;
 caddr_t call_data;
     {
-    (void)MMfreeGarbage(w);
+    (void)wafeMMfreeGarbage(w);
     }
 
 
@@ -474,7 +475,7 @@ caddr_t call_data;
 #include <Xm/DragDrop.h>
 
 #include <Xm/DragDrop.h>
-#define convertSpecialResources(command,w,class,argc,argv) {ArgList           args; int               numArgs; XtInitializeWidgetClass(class); if (convert(ParentWidget(w), class, argv, &argc, &args, &numArgs, w)) { command(w, args, numArgs); wafeCurrentAttribList = NULL; XtFree((String)args); } }
+#define convertSpecialResources(command,w,class,argc,argv) {ArgList           args; int               numArgs; XtInitializeWidgetClass(class); if (wafeConvert(ParentWidget(w), class, argv, &argc, &args, &numArgs, w)) { command(w, args, numArgs); wafeCurrentAttribList = NULL; XtFree((String)args); } }
 
 /* 
  * void
@@ -485,8 +486,8 @@ caddr_t call_data;
  * 	in: [args avp]          # drop site resources
  */
 
-int 
-com_XmDropSiteRegister(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropSiteRegister(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -500,13 +501,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("XmDropSiteRegister","at least ",2,argc);
+	 wafeArgcError("XmDropSiteRegister","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropSiteRegister","2",argv[1],"Widget");
+          wafeConvError("XmDropSiteRegister","2",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -514,14 +515,14 @@ char        **argv;
      argvArg = &argv[2];
      if (argc == 1)
         {
-        if (mergeArguments(argv[2],"XmDropSiteRegister",&argc,&argvArg))
+        if (wafeMergeArguments(argv[2],"XmDropSiteRegister",&argc,&argvArg))
            freeArgv = True;
         else 
            DBUG_RETURN (TCL_ERROR);
         }
      if (argc%2)
         {
-        argcError("XmDropSiteRegister","even number of arguments such as 2 or ",4,argc+1);
+        wafeArgcError("XmDropSiteRegister","even number of arguments such as 2 or ",4,argc+1);
         if (freeArgv) XtFree((char*)argvArg);
         DBUG_RETURN (TCL_ERROR);
         }
@@ -542,8 +543,8 @@ char        **argv;
  * 	in: [args avp]          # drop site resources
  */
 
-int 
-com_XmDropSiteUpdate(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropSiteUpdate(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -557,13 +558,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("XmDropSiteUpdate","at least ",2,argc);
+	 wafeArgcError("XmDropSiteUpdate","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropSiteUpdate","2",argv[1],"Widget");
+          wafeConvError("XmDropSiteUpdate","2",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -571,14 +572,14 @@ char        **argv;
      argvArg = &argv[2];
      if (argc == 1)
         {
-        if (mergeArguments(argv[2],"XmDropSiteUpdate",&argc,&argvArg))
+        if (wafeMergeArguments(argv[2],"XmDropSiteUpdate",&argc,&argvArg))
            freeArgv = True;
         else 
            DBUG_RETURN (TCL_ERROR);
         }
      if (argc%2)
         {
-        argcError("XmDropSiteUpdate","even number of arguments such as 2 or ",4,argc+1);
+        wafeArgcError("XmDropSiteUpdate","even number of arguments such as 2 or ",4,argc+1);
         if (freeArgv) XtFree((char*)argvArg);
         DBUG_RETURN (TCL_ERROR);
         }
@@ -596,8 +597,8 @@ char        **argv;
  * 	in: Widget		# Widget to be unregistered
  */
 
-int 
-com_XmDropSiteUnregister(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropSiteUnregister(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -609,13 +610,13 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("XmDropSiteUnregister","",1,argc);
+	 wafeArgcError("XmDropSiteUnregister","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropSiteUnregister","1",argv[1],"Widget");
+          wafeConvError("XmDropSiteUnregister","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -631,8 +632,8 @@ char        **argv;
  * 	in: Widget		# Widget to identify shell with multiple drop sites
  */
 
-int 
-com_XmDropSiteStartUpdate(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropSiteStartUpdate(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -644,13 +645,13 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("XmDropSiteStartUpdate","",1,argc);
+	 wafeArgcError("XmDropSiteStartUpdate","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropSiteStartUpdate","1",argv[1],"Widget");
+          wafeConvError("XmDropSiteStartUpdate","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -666,8 +667,8 @@ char        **argv;
  * 	in: Widget		# Widget to identify shell with multiple drop sites
  */
 
-int 
-com_XmDropSiteEndUpdate(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropSiteEndUpdate(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -679,13 +680,13 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("XmDropSiteEndUpdate","",1,argc);
+	 wafeArgcError("XmDropSiteEndUpdate","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropSiteEndUpdate","1",argv[1],"Widget");
+          wafeConvError("XmDropSiteEndUpdate","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -701,15 +702,15 @@ char        **argv;
 /* 
  * WidgetID (WidgetID)
  * createDnDWidget4 vulgo XmDropTransferStart
- *         pre: { ArgList args; int numArgs; currentDragContext = localVar1; convert(localVar1,xmDropTransferObjectClass,argvArg,&argc,&args,&numArgs, NULL);
+ *         pre: { ArgList args; int numArgs; currentDragContext = localVar1; wafeConvert(localVar1,xmDropTransferObjectClass,argvArg,&argc,&args,&numArgs, NULL);
  *         const: XmDropTransferStart
  * 	in: Widget		# Drag Context
  * 	in: [args avp]          # Drop Transfer Resources
- *         post: MMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtFree((char*)args); }
+ *         post: wafeMMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtFree((char*)args); }
  */
 
-int 
-com_XmDropTransferStart(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDropTransferStart(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -725,13 +726,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("XmDropTransferStart","at least ",2,argc);
+	 wafeArgcError("XmDropTransferStart","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDropTransferStart","2",argv[1],"Widget");
+          wafeConvError("XmDropTransferStart","2",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -739,21 +740,21 @@ char        **argv;
      argvArg = &argv[2];
      if (argc == 1)
         {
-        if (mergeArguments(argv[2],"XmDropTransferStart",&argc,&argvArg))
+        if (wafeMergeArguments(argv[2],"XmDropTransferStart",&argc,&argvArg))
            freeArgv = True;
         else 
            DBUG_RETURN (TCL_ERROR);
         }
      if (argc%2)
         {
-        argcError("XmDropTransferStart","even number of arguments such as 2 or ",4,argc+1);
+        wafeArgcError("XmDropTransferStart","even number of arguments such as 2 or ",4,argc+1);
         if (freeArgv) XtFree((char*)argvArg);
         DBUG_RETURN (TCL_ERROR);
         }
 
-     { ArgList args; int numArgs; currentDragContext = localVar1; convert(localVar1,xmDropTransferObjectClass,argvArg,&argc,&args,&numArgs, NULL);
+     { ArgList args; int numArgs; currentDragContext = localVar1; wafeConvert(localVar1,xmDropTransferObjectClass,argvArg,&argc,&args,&numArgs, NULL);
      returnVar = (WidgetID) createDnDWidget4(XmDropTransferStart,localVar1,argc,argvArg);
-     MMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtFree((char*)args); }
+     wafeMMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtFree((char*)args); }
      if (freeArgv) XtFree((char *)argvArg);
 
      sprintf(conversionBuffer, "%ld", returnVar);
@@ -766,16 +767,16 @@ char        **argv;
 /* 
  * WidgetID (WidgetID)
  * createDnDWidget5 vulgo XmDragStart
- *         pre: { ArgList args; int numArgs; convert(localVar1,xmDragContextClass,argvArg,&argc,&args,&numArgs, NULL);
+ *         pre: { ArgList args; int numArgs; wafeConvert(localVar1,xmDragContextClass,argvArg,&argc,&args,&numArgs, NULL);
  *         const: XmDragStart
  * 	in: Widget		# Widget (source for drag and drop)
  * 	const: wafeCurrentEvent
  * 	in: [args avp]          # Drag Context Resources
- *         post: MMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtVaSetValues((Widget)returnVar,XmNconvertProc,convertSelectionIncrProc); XtFree((char*)args); }
+ *         post: wafeMMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtVaSetValues((Widget)returnVar,XmNconvertProc,convertSelectionIncrProc); XtFree((char*)args); }
  */
 
-int 
-com_XmDragStart(clientData, comInterpreter, argc, argv)
+static int 
+cmd_XmDragStart(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -791,13 +792,13 @@ char        **argv;
 
      if (argc < 3) 
 	 {
-	 argcError("XmDragStart","at least ",2,argc);
+	 wafeArgcError("XmDragStart","at least ",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("XmDragStart","2",argv[1],"Widget");
+          wafeConvError("XmDragStart","2",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -805,21 +806,21 @@ char        **argv;
      argvArg = &argv[2];
      if (argc == 1)
         {
-        if (mergeArguments(argv[2],"XmDragStart",&argc,&argvArg))
+        if (wafeMergeArguments(argv[2],"XmDragStart",&argc,&argvArg))
            freeArgv = True;
         else 
            DBUG_RETURN (TCL_ERROR);
         }
      if (argc%2)
         {
-        argcError("XmDragStart","even number of arguments such as 2 or ",4,argc+1);
+        wafeArgcError("XmDragStart","even number of arguments such as 2 or ",4,argc+1);
         if (freeArgv) XtFree((char*)argvArg);
         DBUG_RETURN (TCL_ERROR);
         }
 
-     { ArgList args; int numArgs; convert(localVar1,xmDragContextClass,argvArg,&argc,&args,&numArgs, NULL);
+     { ArgList args; int numArgs; wafeConvert(localVar1,xmDragContextClass,argvArg,&argc,&args,&numArgs, NULL);
      returnVar = (WidgetID) createDnDWidget5(XmDragStart,localVar1,wafeCurrentEvent,argc,argvArg);
-     MMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtVaSetValues((Widget)returnVar,XmNconvertProc,convertSelectionIncrProc); XtFree((char*)args); }
+     wafeMMsetAttribList((Widget)returnVar); wafeCurrentAttribList = NULL; XtAddCallback((Widget)returnVar,XtNdestroyCallback,CBfreeAttribs,NULL); XtVaSetValues((Widget)returnVar,XmNconvertProc,convertSelectionIncrProc); XtFree((char*)args); }
      if (freeArgv) XtFree((char *)argvArg);
 
      sprintf(conversionBuffer, "%ld", returnVar);
@@ -830,16 +831,15 @@ char        **argv;
 
 
 #else
-#include "wafe.h"
 #endif
 
 void
-Initialize_Xm12Gen()
+wafeInitialize_Xm12Gen()
 {
 #ifdef MOTIF12
- createWidgetCommand("XmDropSiteManager",xmDropSiteManagerObjectClass,NULL,False);
- createWidgetCommand("XmDragContext",xmDragContextWidgetClass,NULL,False);
- createWidgetCommand("XmDropTransfer",xmDropTransferObjectClass,NULL,False);
+ wafeCreateWidgetCommand("XmDropSiteManager",xmDropSiteManagerObjectClass,NULL,False);
+ wafeCreateWidgetCommand("XmDragContext",xmDragContextWidgetClass,NULL,False);
+ wafeCreateWidgetCommand("XmDropTransfer",xmDropTransferObjectClass,NULL,False);
 #ifdef MOTIF12
  strcat(wafePackages,"MOTIF12 ");
 #endif
@@ -869,13 +869,13 @@ Initialize_Xm12Gen()
  qtransferProc = WafePermStringToQuark("transferProc");
  qconvertProc = WafePermStringToQuark("convertProc");
  qclientData = WafePermStringToQuark("clientData");
- Tcl_CreateCommand(wafeInterpreter, "XmDropSiteRegister", com_XmDropSiteRegister, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDropSiteUpdate", com_XmDropSiteUpdate, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDropSiteUnregister", com_XmDropSiteUnregister, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDropSiteStartUpdate", com_XmDropSiteStartUpdate, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDropSiteEndUpdate", com_XmDropSiteEndUpdate, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDropTransferStart", com_XmDropTransferStart, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "XmDragStart", com_XmDragStart, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropSiteRegister", cmd_XmDropSiteRegister, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropSiteUpdate", cmd_XmDropSiteUpdate, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropSiteUnregister", cmd_XmDropSiteUnregister, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropSiteStartUpdate", cmd_XmDropSiteStartUpdate, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropSiteEndUpdate", cmd_XmDropSiteEndUpdate, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDropTransferStart", cmd_XmDropTransferStart, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "XmDragStart", cmd_XmDragStart, NULL, NULL);
 
 #else
 #endif
