@@ -39,12 +39,12 @@
 typedef struct 
     {
     WidgetClass  wClass;
-    Widget       (*fptr)();
+    Widget       (*wCreateFunction)();
     Boolean      createsShell;
     } wComInfo, *wComInfoPtr;
 
 
-int
+static int
 tclWidgetCommand(clientData, comInterpreter, argc, argv)
 ClientData   clientData;
 Tcl_Interp  *comInterpreter;
@@ -53,7 +53,7 @@ char       **argv;
     {
     Widget         father, new;
     WidgetClass    wClass;
-    Widget         (*fptr)();
+    Widget         (*wCreateFunction)();
     char          *name;
     char          *widgetTyp;
     ArgList        args;
@@ -62,20 +62,28 @@ char       **argv;
     Boolean        managed = True,
                    freeArgv = False,
                    mustManuallyManage = False;
-
+    static char intBuffer[INT_AS_STRING];
 
     DBUG_ENTER("tclWidgetCommand");
 
     widgetTyp = *argv;
     name = *(++argv);
 
+    if (!name || !*name || (*name <= '9' && *name >= '0') ||
+	*name == '-' || *name == '*' || *name == '.')
+	{
+	fprintf(stderr, 
+		"Wafe: Widget name should start with an alphabetic character: <%s>!\n", 
+		name);
+	}
+
     wClass = ((wComInfoPtr)clientData)->wClass;
-    fptr = ((wComInfoPtr)clientData)->fptr;
+    wCreateFunction = ((wComInfoPtr)clientData)->wCreateFunction;
     argv++;
     
 
     /* will open shell on a different display */
-    if (fptr == XtAppCreateShell)
+    if (wCreateFunction == XtAppCreateShell)
 	displayString = *argv;
     else 
 	if ((((wComInfoPtr)clientData)->createsShell))
@@ -109,7 +117,7 @@ char       **argv;
          * and replace argc and argv if so
          */
 	if (argc == 1) 
-	    if (mergeArguments(*argv,widgetTyp,&argc,&argv))
+	    if (wafeMergeArguments(*argv,widgetTyp,&argc,&argv))
 		freeArgv = True;
 
 	/* argc must now be even  
@@ -132,79 +140,84 @@ char       **argv;
 	}
 
     
-    if (convert(father, wClass, argv, &argc, &args, &numArgs, NULL))
+    if (wafeConvert(father, wClass, argv, &argc, &args, &numArgs, NULL))
 	{
-	if (fptr == NULL) /* no special create procedure used */
+	if (wCreateFunction == NULL) /*no special create procedure used*/
 	    {
 	    new = (managed ? XtCreateManagedWidget : XtCreateWidget)
 		(name, wClass, father, args, numArgs);
 	    }
 	else 
-	    if (fptr == XtCreatePopupShell) 
-		{
-		new = XtCreatePopupShell(name, wClass, father, args, numArgs);
-		MOTIF_EDITRES_HANDLER(new);
-		if (!managed)
-		    fprintf(stderr, 
-			    "Wafe(%s): Warning: can't create unmanaged shell; shell is managed\n", 
-			    widgetTyp);
-		}
-	    else
-		if (fptr == XtAppCreateShell) 
-		    {
-		    Display *dpy;
+	if (wCreateFunction == XtCreatePopupShell) 
+	    {
+	    new = XtCreatePopupShell(name, wClass, father, args, numArgs);
+	    MOTIF_EDITRES_HANDLER(new);
+	    if (!managed)
+		fprintf(stderr, 
+	     	    "Wafe(%s): Warning: can't create unmanaged shell; shell is managed\n", 
+		     widgetTyp);
+	    }
+	else
+	if (wCreateFunction == XtAppCreateShell) 
+	    {
+       	    Display *dpy;
 #ifdef PRER5
-		    Cardinal null = 0;
-		    Cardinal *argc = &null;
+	    Cardinal null = 0;
+	    Cardinal *argc = &null;
 #else
-		    int null = 0;
-		    int *argc = &null;
+	    int null = 0;
+	    int *argc = &null;
 #endif
 
-		    dpy = XtOpenDisplay(wafeAppContext,displayString, 
-					Nil(char), Nil(char), 
-					Nil(XrmOptionDescRec), 0, 
-					argc, Nil(String));
-		    if (dpy == NULL) 
-			{
+	    dpy = XtOpenDisplay(wafeAppContext,displayString, 
+				Nil(char), Nil(char), 
+				Nil(XrmOptionDescRec), 0, 
+				argc, Nil(String));
+	    if (dpy == NULL) 
+	         {
 #ifdef RETURN_EMSG
-			char errorBuffer[200];
-			sprintf(errorBuffer,
-				"Wafe(%s): cannot open display <%s>",
-				widgetTyp, displayString);
-			Tcl_SetResult(wafeInterpreter, errorBuffer, TCL_VOLATILE);
+		 char errorBuffer[200];
+		 sprintf(errorBuffer,
+			 "Wafe(%s): cannot open display <%s>",
+			 widgetTyp, displayString);
+		 Tcl_SetResult(wafeInterpreter, errorBuffer, TCL_VOLATILE);
 #else    
-			fprintf(stderr, "Wafe(%s): cannot open display <%s>\n",
-				widgetTyp, displayString);
+		 fprintf(stderr, "Wafe(%s): cannot open display <%s>\n",
+			 widgetTyp, displayString);
 #endif
-			DBUG_RETURN (TCL_ERROR);
-			}
-		    new = XtAppCreateShell(XtName(wafeTopLevel), 
-					   wafeAppClass, wClass, dpy, 
-					   args, numArgs);
-		    addToEndOfWidgetList(&wafeWidgetTrees, 
-					 new, XtNewString(name));
-		    MOTIF_EDITRES_HANDLER(new);
-		    if (!managed)
-			fprintf(stderr, 
-				"Wafe(%s): Warning: cannot create unmanaged shell; shell is managed\n", widgetTyp);
-		    }
-		else
-		    {
-		    /* Use function pointer to create widget */
-		    new = (*fptr)(father, name, args, numArgs);
-		    /* delay manage until all resources are set */
-		    mustManuallyManage = managed; 
+		 DBUG_RETURN (TCL_ERROR);
+	         }
+	    new = XtAppCreateShell(XtName(wafeTopLevel), 
+				   wafeAppClass, wClass, dpy, 
+				   args, numArgs);
+	    wafeAddToEndOfWidgetList(&wafeWidgetTrees, 
+				     new, XtNewString(name));
+	    MOTIF_EDITRES_HANDLER(new);
+	    if (!managed)
+	      fprintf(stderr, 
+		      "Wafe(%s): Warning: cannot create unmanaged shell; shell is managed\n", widgetTyp);
+	    }
+	else
+	if (wCreateFunction == WafeDontManage) 
+	    {
+	    XtCreateWidget(name, wClass, father, args, numArgs);
+	    }
+        else
+	    {
+	    /* Use function pointer to create widget */
+	    new = (*wCreateFunction)(father, name, args, numArgs);
+	    /* delay manage until all resources are set */
+	    mustManuallyManage = managed; 
 
-		    /* these commands create as a side effect a parent shell */
-		    if ((((wComInfoPtr)clientData)->createsShell))
-			{
-			MOTIF_EDITRES_HANDLER(XtParent(new));
-			}
-		    }
+	    /* these commands create as a side effect a parent shell */
+	    if ((((wComInfoPtr)clientData)->createsShell))
+	        {
+		MOTIF_EDITRES_HANDLER(XtParent(new));
+	        }
+	}
 
 
-	MMsetAttribList(new); /*set attriblist(new) = wafeCurrentAttribList) */
+	wafeMMsetAttribList(new); /*set attriblist(new) = wafeCurrentAttribList) */
 
 /* 
     the only place where we could hide the attribListptr in
@@ -238,19 +251,19 @@ char       **argv;
 	 * now convert attributes that need the real widget 
          */
 	if (argc>0) 
-	  {
-	    if (convert(father, wClass, argv, &argc, &args, &numArgs, new))
-	      {
+	    {
+	    if (wafeConvert(father, wClass, argv, &argc, &args, &numArgs, new))
+		{
 		XtSetValues(new, args, numArgs);
 		XtFree((String)args);
-	      }
-	  }
-
-	if (mustManuallyManage) 
-	  XtManageChild(new);
+		}
+	    }
+	if (mustManuallyManage && XtIsRectObj(new)) 
+	    XtManageChild(new);
 
 	wafeCurrentAttribList = NULL;
-	Tcl_ResetResult(wafeInterpreter);
+	sprintf(intBuffer,"%ld",(long)new);
+	Tcl_SetResult(wafeInterpreter,intBuffer,TCL_STATIC);
 	DBUG_RETURN(TCL_OK);
 	}
 	
@@ -265,7 +278,7 @@ char       **argv;
 	Tcl_SetResult(wafeInterpreter, errorBuffer, TCL_VOLATILE);
 	}
 #else    
-    fprintf(stderr, "Couldn't create %s %s widget named <%s>\n", 
+    fprintf(stderr, "Wafe: Couldn't create %s %s widget named <%s>\n", 
 	    managed? "managed": "unmanaged",
 	    widgetTyp, name);
 #endif
@@ -274,7 +287,7 @@ char       **argv;
     DBUG_RETURN(TCL_ERROR);
     }
        
-int
+static int
 warningCommand(clientData, comInterpreter, argc, argv)
 ClientData   clientData;
 Tcl_Interp  *comInterpreter;
@@ -290,15 +303,15 @@ char       **argv;
     }
 
 void 
-createWidgetCommand(command, wClass, fptr, createsShell)
+wafeCreateWidgetCommand(command, wClass, wCreateFunction, createsShell)
 char *command;
 WidgetClass wClass;
-Widget (*fptr)();
+Widget (*wCreateFunction)();
 Boolean createsShell;
     {
     wComInfoPtr  wInfoPtr;
 
-    DBUG_ENTER("createWidgetCommand");
+    DBUG_ENTER("wafeCreateWidgetCommand");
 
     if (!wClass)
 	{
@@ -312,7 +325,7 @@ Boolean createsShell;
 
     wInfoPtr = (wComInfoPtr)XtMalloc(sizeof(wComInfo));
     wInfoPtr->wClass = wClass;
-    wInfoPtr->fptr = fptr;
+    wInfoPtr->wCreateFunction = wCreateFunction;
     wInfoPtr->createsShell = createsShell;
 
     Tcl_CreateCommand(wafeInterpreter, command, 
