@@ -5,9 +5,19 @@
 #include "wafe.h"
 #include "version.h"
 #include <sys/wait.h>
+#include <fcntl.h>
+
+#define EXTRA_HANDLERS 16
+
+/* from AIX man page */
+#define CMD_BUF_SIZE		32764
+#define COM_BUF_SIZE		32764
+#define STDIN_BUF_SIZE		10240
+#define STDERR_BUF_SIZE		10240
+#define EXTRA_BUF_SIZE		10240
 
 /* global variables for signal handling */
-char *tclHandlers[HANDLERMAX];
+char *wafeHandlers[HANDLERMAX];
 static char *tclIntHandlers[SIGMAX];
 
 static Boolean intPending[SIGMAX];
@@ -15,7 +25,7 @@ static Boolean duringEval    = False;
 static int     anyIntPending = 0;
 
 /* global variables for io handlers */
-char   promptChar = '%';
+char   wafePromptChar  = '%';
 static char *comBuffer = NULL;
 
 static char  *communicationHandlerVarname = NULL;
@@ -28,7 +38,7 @@ static Boolean stdoutHandlerRegistered = False;
 static Boolean stderrHandlerRegistered = False;
 static Boolean interactiveMode;
 
-static char  inputBuffer[BUF_SIZE+2];
+static char  inputBuffer[CMD_BUF_SIZE+2];
 static int   leftBytes = 0;      
 
 extern int Tcl_ListCmd(
@@ -46,7 +56,7 @@ static Tcl_DString tclCommand;	/* Used to buffer incomplete
  * initCom (Class InitCom) can be used to start an interpreter
  */
 
-extern void execActionProc(
+extern void wafeExecActionProc(
 #if NeedFunctionPrototypes
      Widget, XEvent *, char **, Cardinal *
 #endif
@@ -57,19 +67,20 @@ typedef struct {
   } AppData, *AppDataPtr;
 
 static AppData    app_data;
-static XtResource resources[] = 
-     {
-     "initCom",
-     "InitCom",
-     XtRString,
-     sizeof(String),
-     XtOffset(AppDataPtr, init_com),
-     XtRImmediate,
-     "",
-     };
+static XtResource resources[] = {
+	{
+	"initCom",
+	"InitCom",
+	XtRString,
+	sizeof(String),
+	XtOffset(AppDataPtr, init_com),
+	XtRImmediate,
+	"",
+	}
+    };
 
 static XtActionsRec    tclAction[] = {
-    {"exec",  execActionProc},
+    {"exec",  wafeExecActionProc},
     };
 
 
@@ -82,7 +93,7 @@ static XtActionsRec    tclAction[] = {
 
 
 void 
-convError (tclCommand, argc, tclArg, type)
+wafeConvError (tclCommand, argc, tclArg, type)
 char * tclCommand;
 char * argc;
 char * tclArg;
@@ -103,7 +114,7 @@ char * type;
 
 
 void
-argcError (tclCommand, quant, tclArgs, argc)
+wafeArgcError (tclCommand, quant, tclArgs, argc)
 char *tclCommand;
 char *quant;
 int   tclArgs;
@@ -123,7 +134,7 @@ int   argc;
     }
 
 void
-noVarCompError (tclCommand, name, comp)
+wafeNoVarCompError (tclCommand, name, comp)
 char *tclCommand;
 char *name;
 char *comp;
@@ -149,12 +160,12 @@ wafeEval(interp, cmd, context)
     char *context;
     {
     int rc, sig;
-    void sigcldHandler();
+    static void sigcldHandler();
     
     DBUG_PRINT(context, ("command: <%s>", cmd));
 
     duringEval = True;
-    if ((rc = Tcl_Eval(interp,cmd)) == TCL_ERROR) 
+    if ((rc = Tcl_GlobalEval(interp,cmd)) == TCL_ERROR) 
 	{ 
 	char *line = strtok(cmd,"\n");
 	int   currLine = 1;
@@ -171,7 +182,8 @@ wafeEval(interp, cmd, context)
 	}
     else
 	{
-	if (interactiveMode && *interp->result != 0) 
+/*	if (interactiveMode && *interp->result != 0) */
+	if (interactiveMode && !strcmp(context,"eval")) 
 	    fprintf(stderr, "#R: {%s}\n",interp->result);
 	}
     
@@ -180,10 +192,12 @@ wafeEval(interp, cmd, context)
     if (anyIntPending) 
 	{
 	for (sig=0; sig < SIGMAX; sig++)
-	    {
-	    (void) wafeEval(interp, tclIntHandlers[sig], "sigPending");
-	    break;
-	    }
+	    if (intPending[sig])
+		{
+		(void) wafeEval(interp, tclIntHandlers[sig], "sigPending");
+		intPending[sig] = False;
+		break;
+		}
 	anyIntPending --;
 	}
 
@@ -200,7 +214,7 @@ wafeEval(interp, cmd, context)
 #define SUBST_VARS
 
 Boolean
-mergeArguments(arguments,context,argc,argv)
+wafeMergeArguments(arguments,context,argc,argv)
 char        *arguments;
 char        *context;
 int        * argc;
@@ -214,7 +228,7 @@ char      ***argv;
 	p++;
 	}
 
-    if (Tcl_VarEval(wafeInterpreter,"llist ", arguments, NULL) == TCL_ERROR)
+    if (Tcl_VarEval(wafeInterpreter,"list ", arguments, NULL) == TCL_ERROR)
 	{
 	fprintf(stderr,"Wafe(%s): %s\n",context,wafeInterpreter->result);
 	return False;
@@ -256,7 +270,7 @@ char      ***argv;
  *    Used by:   main                                                      
  *****************************************************************************/
 
-void
+static void
 signalHandler(sig)
 int   sig;
     {
@@ -293,7 +307,7 @@ int   sig;
     DBUG_VOID_RETURN;
     }
 
-void
+static void
 sigcldHandler(sig)
 int   sig;
     {
@@ -315,17 +329,16 @@ int   sig;
  *****************************************************************************/
 
 static int
-IOErrorHandler(dpy,xe)
+IOErrorHandler(dpy)
 Display *dpy;
-XErrorEvent *xe;
     {
-    char buffer[50];
+    char buffer[200];
     
     DBUG_ENTER ("IOErrorHandler");
 
-    if (tclHandlers[XIOERR])
+    if (wafeHandlers[XIOERR])
 	{
-	sprintf(buffer,"%s %s",tclHandlers[XIOERR],DisplayString(dpy));
+	sprintf(buffer,"%s %s",wafeHandlers[XIOERR],DisplayString(dpy));
 	(void) wafeEval(wafeInterpreter, buffer, "XIOERR");
 	}
 
@@ -348,11 +361,11 @@ static void
 outputBuffer(buffer) 
 char * buffer;
     {
-    if (tclHandlers[STDOUT])
+    if (wafeHandlers[STDOUT])
 	{                    
 	Tcl_SetVar(wafeInterpreter, "STDOUT", buffer, 
 		   TCL_GLOBAL_ONLY);
-	(void) wafeEval(wafeInterpreter, tclHandlers[STDOUT], "STDOUT");
+	(void) wafeEval(wafeInterpreter, wafeHandlers[STDOUT], "STDOUT");
 	}
     else
 	fprintf(stdout,"%s",buffer);
@@ -375,25 +388,24 @@ XtInputId   *xid;
 
     DBUG_ENTER("getInput");
 
-/*fprintf(stderr, "reading inputBuffer=%p, bufptr=%p, left=%d, can read=%d\n",
-	   inputBuffer, bufferPtr, leftBytes, BUF_SIZE-leftBytes);
- */
-
-    if ((readBytes = read(*fid, bufferPtr, BUF_SIZE - leftBytes)) == -1)
+    DBUG_PRINT("io",
+         ("reading inputBuffer=%p, bufptr=%p, left=%d, can read=%d", 
+	  inputBuffer, bufferPtr, leftBytes, CMD_BUF_SIZE-leftBytes));
+ 
+    if ((readBytes = read(*fid, bufferPtr, CMD_BUF_SIZE - leftBytes)) == -1)
 	perror("Wafe: Communication error: ");
 
-/*fprintf(stderr, "read inputBuffer= %p, bufptr=%p, readBytes=%d, size=%d\n",
-	    inputBuffer, bufferPtr, readBytes, leftBytes+readBytes);
- */
+    DBUG_PRINT("io",
+         ("read inputBuffer= %p, bufptr=%p, readBytes=%d, size=%d",
+	    inputBuffer, bufferPtr, readBytes, leftBytes+readBytes));
     
     *(bufferPtr + readBytes) = '\0';
    
-    DBUG_PRINT("socketAll", 
-               ("BufferContents are:\n>>%s<<", bufferPtr));     
+    DBUG_PRINT("io", ("BufferContents are:\n<%s>", bufferPtr));     
 
     if (!readBytes)
 	{
-	fprintf(stderr, "Wafe: eof on primary input channel, bye.\n");
+	DBUG_PRINT("io",("Wafe: eof on primary input channel, bye.\n"));
 	exit(1);
 	}    
  
@@ -403,7 +415,7 @@ XtInputId   *xid;
 	while ((*firstPtr != '\n') && (*firstPtr != '\0'))
 	    firstPtr++;
 
-	if (*firstPtr == '\n') /* One tcl-command is ready */
+	if (*firstPtr == '\n') /* One buffer is ready */
 	    {
 	    char saveChar;
 	    
@@ -412,12 +424,11 @@ XtInputId   *xid;
 	    saveChar = *(firstPtr+1);
 	    *(firstPtr+1) = '\0';
 	    
-	    DBUG_PRINT("socket", 
-		       ("Parsed Command >%s<", secondPtr));
+	    DBUG_PRINT("io", ("Parsed Command <%s>", secondPtr));
 	    
 	    if (client_data)   /* Standard Mode, checking magic chars */
 		{
-		if (*secondPtr == promptChar) 
+		if (*secondPtr == wafePromptChar) 
 		    {
 		    ++secondPtr;
 		    evalCommand = True;
@@ -516,10 +527,12 @@ XtInputId   *xid;
 			}
 		    
 		    }
-		else 
+		else  /* no assignment character, evaluate the command */
 		    {
-		    /* no assignment character, evaluate the command */
-		    if (waitingForCompletion)
+		    /* for inner Event loops or incomplete commands
+		       the command buffer has to be copied
+		     */
+		    if (waitingForCompletion || wafeInnerEventLoop)
 			{
 			char *cmd = Tcl_DStringAppend(&tclCommand, 
 						secondPtr, -1);
@@ -565,10 +578,11 @@ XtInputId   *xid;
 	else
 	    {
 
-/*   fprintf(stderr, "BUFFER without nl leftBytes(%d)+readBytes(%d)=%d < %d\n",
-           leftBytes,readBytes,leftBytes+readBytes,BUF_SIZE);
- */
-	    if (leftBytes + readBytes < BUF_SIZE) 
+	    DBUG_PRINT("io", 
+		 ("BUFFER without nl leftBytes(%d)+readBytes(%d)=%d < %d\n",
+		  leftBytes,readBytes,leftBytes+readBytes,CMD_BUF_SIZE));
+
+	    if (leftBytes + readBytes < CMD_BUF_SIZE) 
 		{
 		leftBytes = readBytes;
 		overFlowFlag = False;
@@ -586,8 +600,8 @@ XtInputId   *xid;
       * it is not terminated with a \n => do buffering 
       */
 
-    DBUG_PRINT("socket", ("incomplete command: <%s>, length=%d", 
-			  secondPtr,firstPtr-secondPtr)); 
+    DBUG_PRINT("io", ("incomplete command: <%s>, length=%d", 
+		      secondPtr,firstPtr-secondPtr)); 
 /*
     strcpy(inputBuffer, secondPtr);
     leftBytes = strlen(inputBuffer);
@@ -608,33 +622,31 @@ int         *fid;
 XtInputId   *xid;
     {
     int     readBytes;
-    char    stdinBuffer[STDIN_BUF_SIZE];
+    char    buffer[STDIN_BUF_SIZE];
 
     DBUG_ENTER("getInputFromStdin");
 
-/*fprintf(stderr,"HERE I AM readin STDIN expecting to read something\n");*/
-
-    if ((readBytes = read(*fid, stdinBuffer, STDIN_BUF_SIZE)) == -1)
+    if ((readBytes = read(*fid, buffer, STDIN_BUF_SIZE)) == -1)
 	perror("getInput");
 
-/* fprintf(stderr,"HERE I AM readin STDIN, got %d bytes!\n", readBytes);*/
-
+    DBUG_PRINT("io", ("reading STDIN, got %d bytes", readBytes));
+    
     if (!readBytes)
 	{
-	DBUG_PRINT("handler",
-		   ("EOF - condition on stdin"));
+	DBUG_PRINT("handler", ("EOF - condition on stdin"));
 	DBUG_VOID_RETURN;
 	}
 
-/* fprintf(stderr,"HERE I AM readin STDIN, string=<%s>\n", stdinBuffer);*/
+/* fprintf(stderr,"HERE I AM readin STDIN, string=<%s>\n", buffer);*/
 
-    if (tclHandlers[STDIN])
+    if (wafeHandlers[STDIN])
 	{
-	Tcl_SetVar(wafeInterpreter, "STDIN", stdinBuffer, TCL_GLOBAL_ONLY);
-	(void) wafeEval(wafeInterpreter, tclHandlers[STDIN], "STDIN");
+	*(buffer + readBytes) = '\0';  /* assure that the string is valid */
+	Tcl_SetVar(wafeInterpreter, "STDIN", buffer, TCL_GLOBAL_ONLY);
+	(void) wafeEval(wafeInterpreter, wafeHandlers[STDIN], "STDIN");
 	}
     else
-	write(wafeToClient, stdinBuffer, readBytes);
+	write(wafeToClient, buffer, readBytes);
 
     DBUG_VOID_RETURN;
     }
@@ -647,35 +659,31 @@ int         *fid;
 XtInputId   *xid;
     {   
     int     readBytes;
-    char    stderrBuffer[STDERR_BUF_SIZE];
+    char    buffer[STDERR_BUF_SIZE];
 
     DBUG_ENTER("stderrHandlerProc");
 
-/*fprintf(stderr,"HERE I AM readin STDERR expecting to read something\n");*/
-
-    if ((readBytes = read(*fid, stderrBuffer, STDERR_BUF_SIZE)) == -1)
+    if ((readBytes = read(*fid, buffer, STDERR_BUF_SIZE-1)) == -1)
 	perror("stderrHandlerProc");
 
-/*fprintf(stderr,"HERE I AM readin STDERR, got %d bytes!\n", readBytes);*/
+    DBUG_PRINT("io", ("reading STDERR, got %d bytes", readBytes));
 
     if (!readBytes)
 	{
-	DBUG_PRINT("handler",
-		   ("EOF - condition on stderr"));
+	DBUG_PRINT("handler", ("EOF - condition on stderr"));
 	DBUG_VOID_RETURN;
 	}
 
-    *(stderrBuffer + readBytes) = '\0';
+/* fprintf(stderr,"***readin STDERR, string=<%s>\n", buffer); */
 
-/*fprintf(stderr,"HERE I AM readin STDERR, string=<%s>\n", stderrBuffer);*/
-
-    if (tclHandlers[STDERR])
+    if (wafeHandlers[STDERR])
 	{
-	Tcl_SetVar(wafeInterpreter, "STDERR", stderrBuffer, TCL_GLOBAL_ONLY);
-	(void) wafeEval(wafeInterpreter, tclHandlers[STDERR], "STDERR");
+	*(buffer + readBytes) = '\0';  /* assure that it is a valid string */
+	Tcl_SetVar(wafeInterpreter, "STDERR", buffer, TCL_GLOBAL_ONLY);
+	(void) wafeEval(wafeInterpreter, wafeHandlers[STDERR], "STDERR");
 	}
     else
-	fprintf(stderr, "%s", stderrBuffer);
+	write(fileno(stderr), buffer, readBytes);
 
     DBUG_VOID_RETURN;
     }
@@ -689,18 +697,18 @@ int         *fid;
 XtInputId   *xid;
     {   
     int     readBytes;
-    char    localComBuffer[COMBUFSIZE+1];
+    char    buffer[COM_BUF_SIZE];
 
     DBUG_ENTER("communicationHandlerProc");
     
-    if ((readBytes = read(*fid, localComBuffer, COMBUFSIZE)) == -1)
+    if ((readBytes = read(*fid, buffer, COM_BUF_SIZE-1)) == -1)
 	perror("communicationHandlerProc");
 
 #ifdef TUNNELDEBUG
     fprintf(stderr, "HandlerProc: I read %d Bytes\n", readBytes); 
 #endif
 
-    *(localComBuffer + readBytes) = '\0';
+    *(buffer + readBytes) = '\0';
 
     communicationCount += readBytes;
 
@@ -711,19 +719,18 @@ XtInputId   *xid;
 
     if (!readBytes)
 	{
-	DBUG_PRINT("handler",
-		     ("EOF - condition on communication channel"));
+	DBUG_PRINT("handler", ("EOF - condition on communication channel"));
 	DBUG_VOID_RETURN;
 	}
 
     if (!comBuffer)
 	{
-	comBuffer = XtNewString(localComBuffer);
+	comBuffer = XtNewString(buffer);
 	}
     else
 	{
 	comBuffer = XtRealloc(comBuffer, strlen(comBuffer) + readBytes + 1);
-	strcat(comBuffer, localComBuffer);
+	strcat(comBuffer, buffer);
 	}
     
     if ((communicationHandlerCommand) && (communicationHandlerLength <= communicationCount))
@@ -764,7 +771,7 @@ XtInputId   *xid;
      }
 
 void
-setCommunicationVariable(varName,length,command)
+wafeSetCommunicationVariableCmd(varName,length,command)
 String   varName;
 int      length;
 String   command;
@@ -854,9 +861,9 @@ String   command;
 */
 
 void 
-doregister(handlerType,string)
+wafeRegisterCmd(handlerType,string)
 int handlerType;
-char *string;
+String string;
     {
     char **table;
 
@@ -903,7 +910,7 @@ char *string;
 	    signal(handlerType,signalHandler);
 	}
     else
-	table = tclHandlers;
+	table = wafeHandlers;
 
     if (table[handlerType]) 
 	XtFree(table[handlerType]);
@@ -912,9 +919,8 @@ char *string;
     } 
 
 
-
 void 
-unregister(handlerType)
+wafeUnregisterCmd(handlerType)
 int handlerType;
     {    
     char **table;
@@ -930,7 +936,7 @@ int handlerType;
 	    signal(handlerType,signalHandler);
 	}
     else
-	table = tclHandlers;
+	table = wafeHandlers;
 
     if (!table[handlerType]) 
 	fprintf(stderr, "Wafe(unregister): Warning, no handler registered!\n");
@@ -939,7 +945,130 @@ int handlerType;
 
     table[handlerType] = NULL;
     }
-     
+
+
+/*
+ * extra input handlers, which are user maintained
+ */
+typedef struct
+    {
+    String varName;
+    String command;
+    XtPointer mask;
+    XtInputId id;
+    } extraInput;
+
+static extraInput extraInputs[EXTRA_HANDLERS];
+
+    
+static void
+extraHandlerProc(clientData, fid, xid)
+XtPointer    clientData;
+int         *fid;
+XtInputId   *xid;
+    {   
+    extraInput *slot = (extraInput *)clientData;
+
+    DBUG_ENTER("extraHandlerProc");
+
+    if (slot->mask == (XtPointer)XtInputReadMask) 
+	{
+	int readBytes;	
+	char buffer[EXTRA_BUF_SIZE];
+
+/*	fprintf(stderr,"***extra: expecting to read something on %d\n",*fid);*/
+	if ((readBytes = read(*fid, buffer, EXTRA_BUF_SIZE-1)) == -1)
+	    perror("extraHandlerProc");
+
+/*	fprintf(stderr,"***extra, got %d bytes\n", readBytes);*/
+	if (!readBytes)
+	    {
+	    DBUG_PRINT("handler", ("EOF - condition on extra"));
+	    DBUG_VOID_RETURN;
+	    }
+
+	if (slot->varName) 
+	    {
+	    *(buffer + readBytes) = '\0'; /* make it a valid string */
+	    /* fprintf(stderr,"***extra string=<%s>\n", buffer); */
+	    Tcl_SetVar(wafeInterpreter,  slot->varName, buffer, 
+		       TCL_GLOBAL_ONLY|TCL_APPEND_VALUE);
+	    }
+	}
+    if (slot->command)
+	(void) wafeEval(wafeInterpreter, slot->command, "extraInput");
+
+    DBUG_VOID_RETURN;
+    }
+
+
+XtInputId
+wafeAddInputCmd(source,condition,varName,command)
+int source;
+XtPointer condition;
+String varName;
+String command;
+    {
+    int i;
+    extraInput *slot = NULL;
+
+    if ((stdinHandlerRegistered  && (fileno(stdin) == source) ) 
+	|| (!fileMode && wafeFromClient == source) 
+	|| (stderrHandlerRegistered && wafeErrorClient == source) 
+       )
+	{
+	fprintf(stderr, "Wafe(addInput): cannot add input handler!\n");
+	return 0;
+	}
+
+    for (i=0; i<EXTRA_HANDLERS; i++) 
+	{
+	if (!(extraInputs[i].id))
+	    {
+	    slot = &extraInputs[i];
+	    break;
+	    }
+	}
+    if (slot) 
+	{
+	slot->varName = XtNewString(varName);
+	slot->command = XtNewString(command);
+	slot->mask = condition;
+	slot->id = XtAppAddInput(wafeAppContext, source, condition,
+				 extraHandlerProc, (XtPointer)slot);
+	return slot->id;
+	}
+    else 
+	{
+	fprintf(stderr,
+		"Wafe(addInput): cannot allocate slot for input handler\n");
+	return 0;
+	}
+    }
+
+void
+wafeRemoveInputCmd(id)
+XtInputId id;
+    {
+    int i;
+    extraInput *slot = NULL;
+
+    for (i=0; i<EXTRA_HANDLERS; i++) 
+	{
+	if (extraInputs[i].id == id)
+	    {
+	    slot = &extraInputs[i];
+	    XtRemoveInput(id);
+	    slot->id = 0;
+	    XtFree(slot->varName);
+	    XtFree(slot->command);
+	    return;
+	    }
+	}
+    fprintf(stderr,"Wafe(removeInput): no such input %lu\n",id);
+    }
+
+
 
 
 void
@@ -952,19 +1081,24 @@ Boolean promptMode;
     int i;
     char *p;
     char intBuffer[INT_AS_STRING];
+    char charBuffer[200];
     Boolean canAddStdinHandler = True;
     
-    extern void callbackQuarkInitialize();
-    extern void Initialize_MiscGen();
-    extern void Initialize_XmGen();
-    extern void Initialize_XawGen();
-    extern void Initialize_XawR5Gen();
-    extern void Initialize_XmGraphGen();
-    extern void Initialize_AtGen();
-    extern void Initialize_htmlwGen();
-    extern void Initialize_XcGen();
-    extern void Initialize_rddGen();
-    extern void Initialize_XtGen();
+    extern void wafeCallbackQuarkInitialize();
+    extern void wafeInitialize_MiscGen();
+    extern void wafeInitialize_XmGen();
+    extern void wafeInitialize_Xm12Gen();
+    extern void wafeInitialize_XawGen();
+    extern void wafeInitialize_XawR5Gen();
+    extern void wafeInitialize_XmGraphGen();
+    extern void wafeInitialize_AtGen();
+    extern void wafeInitialize_htmlwGen();
+#ifdef XC
+    extern void wafeInitialize_XcGen();
+#endif
+    extern void wafeInitialize_rddGen();
+    extern void wafeInitialize_XtGen();
+    static char *defaultFileSearchPath = wafeDefaultFileSearchPath;
 
     wafeInterpreter = Tcl_CreateInterp();
     wafePackages[0] = '\0';    
@@ -976,7 +1110,7 @@ Boolean promptMode;
     if (wafeToClient   == -1) wafeToClient   = fileno(stdout);
 
     /* initialize handlers */
-    for (i=0; i<HANDLERMAX; tclHandlers[i]=NULL, i++); 
+    for (i=0; i<HANDLERMAX; wafeHandlers[i]=NULL, i++); 
     for (i=0; i<SIGMAX; tclIntHandlers[i]=NULL, i++); 
 
     /* setup signal handlers:
@@ -1001,7 +1135,7 @@ Boolean promptMode;
     XSetIOErrorHandler(IOErrorHandler);
 
     /* the default widget tree is under topLevel */
-    addToEndOfWidgetList(&wafeWidgetTrees, wafeTopLevel, "topLevel");
+    wafeAddToEndOfWidgetList(&wafeWidgetTrees, wafeTopLevel, "topLevel");
 
     XtAppAddActions(wafeAppContext, tclAction, 1);
     XtVaGetApplicationResources(wafeTopLevel, &app_data, resources,
@@ -1010,6 +1144,13 @@ Boolean promptMode;
     /* add various Xt inputs depending on mode */
     if (!fileMode)
 	{
+#ifdef _IBMR2
+	if (wafeClientPid) 
+	    {
+            /* fprintf(stderr, "setting FNDELAY for %d\n",wafeFromClient); */
+	    fcntl(wafeFromClient, F_SETFL, FNDELAY);
+	    }
+#endif
 	XtAppAddInput(wafeAppContext, wafeFromClient, 
 		      (XtPointer)XtInputReadMask,
 		      getInput, (XtPointer)(int)promptMode);
@@ -1019,6 +1160,10 @@ Boolean promptMode;
     
     if (wafeClientPid)
 	{ 
+#ifdef _IBMR2
+	/* fprintf(stderr, "setting FNDELAY for %d\n",wafeErrorClient); */
+	fcntl(wafeErrorClient, F_SETFL, FNDELAY);
+#endif
 	XtAppAddInput(wafeAppContext, wafeErrorClient,
 		      (XtPointer)XtInputReadMask, stderrHandlerProc, 
 		      (XtPointer)NULL); 
@@ -1042,7 +1187,8 @@ Boolean promptMode;
 	    }
 	else
 	    {
-	    fprintf(stderr, "Wafe: cannot add input handler in this mode combination!\n");
+	    fprintf(stderr, 
+		    "Wafe: cannot add input handler in this mode combination!\n");
 	    exit(-1);
 	    }
     
@@ -1057,25 +1203,34 @@ Boolean promptMode;
     /*
      * since the athena list widget is created by the command list,
      * we use the name llist instead to list
+    Tcl_CreateCommand(wafeInterpreter, "llist", Tcl_ListCmd, NULL, NULL);
      */
 
-    Tcl_CreateCommand(wafeInterpreter, "llist", Tcl_ListCmd, NULL, NULL);
 
     /* intialize global quarks */
-    callbackQuarkInitialize();
+    wafeCallbackQuarkInitialize();
 
     /* initialize various packages */
-    Initialize_MiscGen();
-    Initialize_XmGen();
-    Initialize_XawGen();
-    Initialize_XawR5Gen();
-    Initialize_XmGraphGen();
-    Initialize_AtGen();
-    Initialize_htmlwGen();
-    Initialize_XcGen();
-    Initialize_rddGen();
-    Initialize_XtGen();   /* should be after Xaw for StringToWidget conv. */
-
+    wafeInitialize_MiscGen();
+    wafeInitialize_XmGen();
+    wafeInitialize_Xm12Gen();
+    wafeInitialize_XawGen();
+    wafeInitialize_XawR5Gen();
+    wafeInitialize_XmGraphGen();
+    wafeInitialize_AtGen();
+    wafeInitialize_htmlwGen();
+#ifdef XC
+    wafeInitialize_XcGen();
+#endif
+    wafeInitialize_rddGen();
+    wafeInitialize_XtGen();  /* should be after Xaw for StringToWidget conv.*/
+#ifdef ITCL
+    if (Itcl_Init(wafeInterpreter) == TCL_ERROR)
+	{
+	fprintf(stderr,"Wafe: could not initialize [incr Tcl]\n");
+	}
+#endif
+    
     /* define global variables */
 #ifdef PRER5
     Tcl_SetVar(wafeInterpreter, "XVERSION", "R4", TCL_GLOBAL_ONLY);
@@ -1117,13 +1272,25 @@ Boolean promptMode;
     else
 	/* it is nesscessary to make a dynamically allocated copy for link var
 	 */
-	wafeFileSearchPath = XtNewString(wafeDefaultFileSearchPath);
+	wafeFileSearchPath = XtNewString(defaultFileSearchPath);
 
     Tcl_LinkVar(wafeInterpreter, "FILESEARCHPATH", 
 		(char *)&wafeFileSearchPath,  TCL_LINK_STRING);
 
     Tcl_DStringInit(&tclCommand);
+    Tcl_Init(wafeInterpreter);
 
+    if (!(p = (char *)getenv("WAFELIB")))
+        p = WAFELIB;
+
+    Tcl_SetVar(wafeInterpreter, "WAFELIB", p, TCL_GLOBAL_ONLY);
+   
+    sprintf(charBuffer,"%s/tcllib",p);
+    Tcl_SetVar(wafeInterpreter, "auto_path", charBuffer, 
+	       TCL_LIST_ELEMENT|TCL_APPEND_VALUE);
+    sprintf(charBuffer,"%s/tcllib/bc",p);
+    Tcl_SetVar(wafeInterpreter, "auto_path", charBuffer, 
+	       TCL_LIST_ELEMENT|TCL_APPEND_VALUE);
     }
 
 
