@@ -13,16 +13,15 @@
  * documentation.  This software is provided "as is" without expressed or
  * implied warranty.
 
- * Creation: Tue Oct 12 04:45:02 MET 1993 on dec1.wu-wien.ac.at
+ * Creation: Sat May 14 16:36:57 GMT 1994 on mohegan
  * Author: genc
- * Version: 0.95999999999999996
+ * Version: 0.96999999999999997335
+
 
  */
-#ifdef RDD
-
 #define RDD_C
-
-#include "wafe.h"
+#include <wafe.h>
+#ifdef RDD
 
 /* 
  * ******* begin required file <rdd.inc> *******
@@ -46,7 +45,7 @@ extern void rddSetDragCursorOffset(
 );
 
 /*
- *  The following command is used to access the Drag'n Drop library 
+ *  The following command is used to access the Drag'n Drop library
  */
 
 
@@ -57,7 +56,7 @@ char     *command;
 RddCallbackStruct   *info;
     {
     char *message;
-     
+
     message = (char *)XtMalloc(info->len + 1);
     strncpy(message, info->data, info->len);
     *(message + info->len) = '\0';
@@ -71,7 +70,7 @@ RddCallbackStruct   *info;
 
 
 /* RDD myStartAction */
-static void 
+static void
 myStartAction (w, event, args, nargs)
 Widget w;
 XButtonEvent *event;
@@ -84,19 +83,19 @@ int *nargs;
     Position  x,y, xRoot, yRoot;
     static GC gc = NULL;
 
-    XtVaGetValues(w, 
-		  XtNx,&x, 
+    XtVaGetValues(w,
+		  XtNx,&x,
 		  XtNy,&y,
 		  XtNwidth, &width,
 		  XtNheight, &height,
 		  NULL);
     XtTranslateCoords(w,x,y,&xRoot,&yRoot);
-    
-    if (pixmap && pixmap != XtUnspecifiedPixmap)
-	XFreePixmap(XtDisplay(w), pixmap);
 
-    fprintf(stderr,"nargs=%d\n",*nargs);
-    
+    if (pixmap && pixmap != XtUnspecifiedPixmap)
+	XFreePixmap(dpy, pixmap);
+
+    /* fprintf(stderr,"nargs=%d\n",*nargs);*/
+
 
     if (*nargs == 1)
 	{
@@ -114,21 +113,21 @@ int *nargs;
 	    Window junkWindow;
 	    pixmap = *(Pixmap *) output.addr;
 
-	    fprintf(stderr,"received pixmap=%d\n",pixmap);	    
-	    XGetGeometry(dpy, pixmap, &junkWindow, &x, &y, 
+	    /*fprintf(stderr,"received pixmap=%d\n",pixmap); */
+	    XGetGeometry(dpy, pixmap, &junkWindow, &x, &y,
 			 &ww, &hh, &border_width, &depth);
-	    fprintf(stderr,"survived xgetgeometry w=%u, h=%u\n",ww,hh);	    
+	    /*fprintf(stderr,"survived xgetgeometry w=%u, h=%u\n",ww,hh); */
 	    height= hh; width = ww;
 	    }
-	else 
+	else
 	    {
 	    pixmap = XtUnspecifiedPixmap;
 	    height = width = 20;
 	    }
 	}
-    else 
+    else
 	{
-	fprintf(stderr,"nargs=%d\n",*nargs);	    
+	/*fprintf(stderr,"nargs=%d\n",*nargs);*/
 	/* get pixmap of widget */
 	if (!gc)		/* probleme mit multiscreen und diff depth */
 	    {
@@ -136,12 +135,12 @@ int *nargs;
 	    gcv.subwindow_mode = IncludeInferiors;
 	    gc = XCreateGC (dpy, XtWindow(w), GCSubwindowMode, &gcv);
 	    }
-	
-	pixmap = XCreatePixmap (dpy, RootWindow(dpy,0), 
+
+	pixmap = XCreatePixmap (dpy, RootWindow(dpy,0),
 				width, height, XDefaultDepth(dpy,0));
 
 	/* Create a pixmap of the widget */
-	
+
 	XCopyArea(dpy, XtWindow(w), pixmap, gc, 0,0, width, height, 0,0);
 	/*          XCopyArea(dpy, RootWindow(dpy,0), pixmap, gc, x,y, width, height, 0,0);*/
 	}
@@ -153,10 +152,10 @@ int *nargs;
     rddSetDragCursorOffset(event->x, event->y);
 
     /* Will take care of global vars bx by */
-    rddStartAction (w, event, args, nargs); 
+    rddStartAction (w, event, args, nargs);
 
 
-    fprintf(stderr,"DONE\n");	    
+    fprintf(stderr,"DONE\n");
     }
 
 /*
@@ -168,14 +167,14 @@ int *nargs;
 static Widget  sh        = NULL;
 static Widget  pixShell  = NULL;
 static int     shXoffset = 0;
-static int     shYoffset = 0;    
+static int     shYoffset = 0;
 
 #define RDD_UNDEF    0
 #define RDD_PIXMAP   1
 #define RDD_USRSHELL 2
 #define RDD_CURSOR   3
 
-static void 
+static void
 rddShStartAction (w, event, args, nargs)
 Widget         w;
 XButtonEvent  *event;
@@ -189,7 +188,7 @@ int           *nargs;
     int           x, y;
     unsigned int  width, height, bw, depth;
     int           mode = RDD_UNDEF;
-    
+
     sh = NULL;
 
     if (*nargs == 0)
@@ -203,18 +202,18 @@ int           *nargs;
     else
     if (*nargs == 2)
 	{
-	if (!strcmp(*args,"pixmap")) 
+	if (!strcmp(*args,"pixmap"))
 	    {
 	    mode = RDD_PIXMAP;
 	    args++;
 	    }
-	else 
-	if (!strcmp(*args,"shell")) 
+	else
+	if (!strcmp(*args,"shell"))
 	    {
 	    mode = RDD_USRSHELL;
 	    args++;
 	    }
-	else 
+	else
 	    {
 	    fprintf(stderr, "rddShStartAction: wrong type <%s>\n", *args);
 	    return;
@@ -225,14 +224,14 @@ int           *nargs;
 	{
 	if (!pixShell)
 	    {
-	    pixShell = XtVaCreatePopupShell("rddSh", 
-					    overrideShellWidgetClass, w, 
-					    XtNmappedWhenManaged, 0,
+	    pixShell = XtVaCreatePopupShell("rddSh",
+					    overrideShellWidgetClass, w,
+					    XtNmappedWhenManaged, False,
 					    XtNwidth, 10,
 					    XtNheight, 10,
 					    NULL);
 
-	    /* Window has to be created right away in 
+	    /* Window has to be created right away in
 	       order to apply a shape mask... */
 	    XtRealizeWidget(pixShell);
 	    }
@@ -243,19 +242,19 @@ int           *nargs;
 
 	if (!outVal.addr)
 	    return;
-    
+
 	shPixmap =  *(Pixmap *)outVal.addr;
-	XGetGeometry(XtDisplay(pixShell), shPixmap, 
+	XGetGeometry(XtDisplay(pixShell), shPixmap,
 		     &rootWin, &x, &y, &width, &height, &bw, &depth);
 
 	shXoffset = width/2;
 	shYoffset = height/2;
 
-	XtVaSetValues(pixShell, 
+	XtVaSetValues(pixShell,
 		      XtNbackgroundPixmap, shPixmap,
 		      XtNwidth,            width,
 		      XtNheight,           height,
-		      XtNx,                event->x_root - shXoffset,  
+		      XtNx,                event->x_root - shXoffset,
 		      XtNy,                event->y_root - shYoffset,
 		      NULL);
 	sh = pixShell;
@@ -263,25 +262,25 @@ int           *nargs;
     else if (mode == RDD_USRSHELL)
 	{
 	Dimension w, h;
-	
+
 	sh = name2Widget(*args);
 	if (!sh)
 	    {
 	    fprintf(stderr, "rddShStartAction: no such shell <%s>\n", *args);
 	    return;
 	    }
-	
+
 	XtRealizeWidget(sh);
 	XtVaGetValues(sh,
 		      XtNwidth,  &w,
 		      XtNheight, &h,
 		      NULL);
-	
+
 	shXoffset = w/2;
 	shYoffset = h/2;
 
-	XtVaSetValues(sh, 
-		      XtNx, event->x_root - shXoffset,  
+	XtVaSetValues(sh,
+		      XtNx, event->x_root - shXoffset,
 		      XtNy, event->y_root - shYoffset,
 		      NULL);
 	}
@@ -298,7 +297,7 @@ String       *args;
 int          *nargs;
     {
     Position x_root = event->x_root;
-    Position y_root = event->y_root;    
+    Position y_root = event->y_root;
 
     if (!sh) return;
 
@@ -310,8 +309,8 @@ int          *nargs;
        XEvent pEvent;
        XMotionEvent *mPtr = (XMotionEvent *)&pEvent;
        XtAppNextEvent(wafeAppContext,&pEvent);
-       while ((pEvent.type == MotionNotify) && 
-              XtAppPending(wafeAppContext) 
+       while ((pEvent.type == MotionNotify) &&
+              XtAppPending(wafeAppContext)
 	     )
           {
           x_root = mPtr->x_root;
@@ -320,10 +319,10 @@ int          *nargs;
           }
        if (pEvent.type != MotionNotify)
 	   XtDispatchEvent(&pEvent);
-       
+
        }
 
-    XMoveWindow(XtDisplay(sh), XtWindow(sh), 
+    XMoveWindow(XtDisplay(sh), XtWindow(sh),
 		x_root - shXoffset,
 		y_root - shYoffset);
 
@@ -353,16 +352,15 @@ int *nargs;
 void
 rddWafeInit()
     {
-    static XtActionsRec actions[] = 
-	{
-	"rddDropAction", (XtActionProc)rddDropAction,
-	"wStartAction", (XtActionProc)myStartAction,
-	"rddStartAction", (XtActionProc)rddStartAction,
-	"rddWafeStartAction", (XtActionProc)rddShStartAction,
-	"rddWafeDragAction", (XtActionProc)rddShDragAction,
-	"rddWafeDropAction", (XtActionProc)rddShDropAction,
-	NULL, NULL,
-	};
+    static XtActionsRec actions[] = {
+	{"rddDropAction", (XtActionProc)rddDropAction},
+	{"wStartAction", (XtActionProc)myStartAction},
+	{"rddStartAction", (XtActionProc)rddStartAction},
+	{"rddWafeStartAction", (XtActionProc)rddShStartAction},
+	{"rddWafeDragAction", (XtActionProc)rddShDragAction},
+	{"rddWafeDropAction", (XtActionProc)rddShDropAction},
+	{NULL, NULL},
+      };
     XtAppAddActions(wafeAppContext, actions, XtNumber(actions));
     rddInit(wafeTopLevel, wafeAppContext);
     }
@@ -385,8 +383,8 @@ rddWafeInit()
  * 	const: strlen(argv[1])
  */
 
-int 
-com_rddSetDropData(clientData, comInterpreter, argc, argv)
+static int 
+cmd_rddSetDropData(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -397,7 +395,7 @@ char        **argv;
 
      if (argc != 2) 
 	 {
-	 argcError("rddSetDropData","",1,argc);
+	 wafeArgcError("rddSetDropData","",1,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
@@ -418,8 +416,8 @@ char        **argv;
 
  */
 
-int 
-com_rddAddDropHandler(clientData, comInterpreter, argc, argv)
+static int 
+cmd_rddAddDropHandler(clientData, comInterpreter, argc, argv)
 ClientData    clientData;
 Tcl_Interp   *comInterpreter;
 int           argc;
@@ -431,13 +429,13 @@ char        **argv;
 
      if (argc != 3) 
 	 {
-	 argcError("rddAddDropHandler","",2,argc);
+	 wafeArgcError("rddAddDropHandler","",2,argc);
 	 DBUG_RETURN (TCL_ERROR);
          }
 
      if (!(localVar1 = (Widget) name2Widget(argv[1])))
           {
-          convError("rddAddDropHandler","1",argv[1],"Widget");
+          wafeConvError("rddAddDropHandler","1",argv[1],"Widget");
           DBUG_RETURN (TCL_ERROR);
           }
 
@@ -450,19 +448,18 @@ char        **argv;
 
 
 #else
-#include "wafe.h"
 #endif
 
 void
-Initialize_rddGen()
+wafeInitialize_rddGen()
 {
 #ifdef RDD
 #ifdef RDD
  strcat(wafePackages,"RDD ");
 #endif
  rddWafeInit();
- Tcl_CreateCommand(wafeInterpreter, "rddSetDropData", com_rddSetDropData, NULL, NULL);
- Tcl_CreateCommand(wafeInterpreter, "rddAddDropHandler", com_rddAddDropHandler, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "rddSetDropData", cmd_rddSetDropData, NULL, NULL);
+ Tcl_CreateCommand(wafeInterpreter, "rddAddDropHandler", cmd_rddAddDropHandler, NULL, NULL);
 
 #else
 #endif
