@@ -1,4 +1,7 @@
 /* dbug needs stdio */
+#undef USECONTEXT
+#undef HASH
+#define LAZY_GETATTRIB
 
 #ifndef DEBUG_MALLOC
 #include <stdlib.h>
@@ -10,6 +13,7 @@
 #include <signal.h>
 
 #include <X11/Intrinsic.h>
+#include <X11/Shell.h>
 #include <X11/StringDefs.h>
 
 #define RETURN_EMSG
@@ -25,26 +29,17 @@
 
 
 #define MESSAGE_COMMAND_LENGTH	4096
-#define INT_AS_STRING 		10
+#ifdef __alpha
+#define LONG_AS_STRING 		22
+#else
+#define LONG_AS_STRING 		12
+#endif
+#define INT_AS_STRING 		12
 #define FLOAT_AS_STRING		20
 #define MAX_NAME_LEN		30
 #define MAX_TYPE_LEN		30
 #define INT_ARRAY_IN_BYTES	4096
 
-#ifdef NEVER
-/*
-#define BUF_SIZE		65536
-#define COMBUFSIZE		65536
-*/
-/* from AIX man page */
-#define BUF_SIZE		32764
-#define COMBUFSIZE		32764
-
-#define STDIN_BUF_SIZE		10240
-#define STDERR_BUF_SIZE		10240
-#define EXTRA_BUF_SIZE		10240
-#endif
-
 #ifndef SIGMAX
 #define SIGMAX NSIG
 #endif
@@ -57,14 +52,14 @@
 #define HTMLVISITED 4
 #define HANDLERMAX HTMLVISITED+1
 
+#define ParentWidget(w)  ((XtParent(w) == NULL) ? w : XtParent(w))
+#define widget2Name(w)   ((XtParent(w) == NULL) ? wafeTopLevelWidget(w) : XtName(w))
 
-#define ParentWidget(w)         ((w) != wafeTopLevel ? XtParent(w) : (w))
-#define widget2Name(w)          ((w) != wafeTopLevel ? XtName(w) : "topLevel")
 #define Nil(Typ)                ((Typ *) 0)
 
-#define name2Widget(name)                 cvtName2Widget(name,True,NULL,NULL)
-#define name2WidgetId(name)               cvtName2Widget(name,False,NULL,NULL)
-#define name2WidgetOfClass(name,c,string) cvtName2Widget(name,True,c,string)
+#define name2Widget(name)              wafeCvtName2Widget(name,True,NULL,NULL)
+#define name2WidgetId(name)            wafeCvtName2Widget(name,False,NULL,NULL)
+#define name2WidgetOfClass(name,c,str) wafeCvtName2Widget(name,True,c,str)
 
 #ifdef PRER5
 #define WafePermStringToQuark(n) XrmStringToQuark((n))
@@ -87,6 +82,14 @@
 	    if (outp.addr)
 #endif
 
+#ifdef MOTIF
+#include <Xm/Xm.h>
+# define MOTIF11
+# if (XmVERSION == 1) && (XmREVISION >= 2)
+#  define MOTIF12
+# endif
+#endif
+
 #if !defined(PRER5) && defined(MOTIF11) && defined(MOTIF_EDITRES)
 #include <X11/Xmu/Editres.h>
 #define MOTIF_EDITRES_HANDLER(w) \
@@ -125,7 +128,19 @@ WAFE_EXTERN String INITIALIZE(wafeScriptName, NULL); /* for fileMode         */
 WAFE_EXTERN String INITIALIZE(wafeAppClass, NULL);
 WAFE_EXTERN char           wafePackages[100];
 WAFE_EXTERN String         wafeFileSearchPath;
+WAFE_EXTERN XEvent*        wafeCurrentEvent;    /* current event for actions */
+WAFE_EXTERN int    INITIALIZE(wafeInnerEventLoop, 0);
 
+#ifdef USECONTEXT
+WAFE_EXTERN XContext INITIALIZE(wafeCtx, 0);
+#endif
+
+#ifdef LAZY_GETATTRIB
+/* in order to make wafeMMgetAttribList more lazy we use a 
+ * global static variable
+ */
+Widget wafeCurrentWidget;
+#endif
 
 /*
  * Some Widgets have subparts or subobjects providing ressources,
@@ -141,6 +156,9 @@ typedef struct
     char *resource_type;
     } addResInfo;
 
+
+typedef long WidgetID;
+
 /* 
  * memory management uses a widget list and 
  * a per widget attibute list keeping the resources to be freed
@@ -197,6 +215,19 @@ WAFE_EXTERN XrmQuark qHorizontalPosition;
 WAFE_EXTERN XrmQuark qVerticalPosition;
 WAFE_EXTERN XrmQuark qPrimForegroundPixmap;
 WAFE_EXTERN XrmQuark qTextPosition;
+WAFE_EXTERN XrmQuark qdropProc;
+WAFE_EXTERN XrmQuark qdragProc;
+WAFE_EXTERN XrmQuark qtransferProc;
+WAFE_EXTERN XrmQuark qconvertProc;
+WAFE_EXTERN XrmQuark qclientData; 
+#define xmDragContextWidgetClass xmDragContextClass
+
+typedef struct
+    {
+    String dest;
+    XtPointer value;
+    } dropTransferCallbackStruct;
+
 #endif
 
 /************** no global variables beyond this point ************/
@@ -231,9 +262,10 @@ typedef struct _QType
 /*************************** externs for callback.c **************/
 
 #ifdef MOTIF11
+/*
 #ifdef CALLBACK_C
 #include <Xm/Xm.h>
-extern void exmString2String(
+extern void wafeEscapedXmString2String(
 #if NeedFunctionPrototypes
      char *, XmString
 #endif
@@ -245,42 +277,43 @@ extern char * xmStringTable2String(
 #endif
 );
 #endif
+*/
 #endif
 
 
 /*************************** externs from mm.c **************/
 #ifndef MM_C
-extern void MMreplace(
+extern void wafeMMreplace(
 #if NeedFunctionPrototypes
     MMattribListPtr *, XrmQuark, char *, freeProc
 #endif
 );
 
-extern MMattribListPtr * MMgetAttribList(
+extern MMattribListPtr * wafeMMgetAttribList(
 #if NeedFunctionPrototypes
-    Widget
+    Widget, Boolean
 #endif
 );
 
-extern Widget MMfreeGarbage(
+extern Widget wafeMMfreeGarbage(
 #if NeedFunctionPrototypes
      Widget
 #endif
 );
 
-extern char * MMgetValue(
+extern char * wafeMMgetValue(
 #if NeedFunctionPrototypes
     MMattribListPtr *, XrmQuark
 #endif
 );
 
-extern void addToEndOfWidgetList(
+extern void wafeAddToEndOfWidgetList(
 #if NeedFunctionPrototypes
      WidgetListPtr *, Widget, XtPointer
 #endif
 );
 
-extern void MMsetAttribList(
+extern void wafeMMsetAttribList(
 #if NeedFunctionPrototypes
       Widget
 #endif
@@ -303,7 +336,7 @@ extern int wafeEval(
 #endif			 
 );
 
-extern Boolean mergeArguments(
+extern Boolean wafeMergeArguments(
 #if NeedFunctionPrototypes
      char *, char *, int *, char ***
 #endif			 
@@ -311,21 +344,21 @@ extern Boolean mergeArguments(
 
 
 void
-convError (
+wafeConvError (
 #if NeedFunctionPrototypes
      char*, char*, char*, char*
 #endif
 );
 
 void
-argcError (
+wafeArgcError (
 #if NeedFunctionPrototypes
      char*, char*, int, int
 #endif
 );
 
 void
-noVarCompError (
+wafeNoVarCompError (
 #if NeedFunctionPrototypes
      char*, char*, char*
 #endif
@@ -337,9 +370,9 @@ noVarCompError (
 /*************************** externs from callback.c **************/
 
 #ifndef CALLBACK_C
-extern void callbackQuarkInitialize();
+extern void wafeCallbackQuarkInitialize();
 
-extern void execCallbackProc(
+extern void wafeExecCallbackProc(
 #if NeedFunctionPrototypes
      Widget, XtPointer, XtPointer
 #endif
@@ -353,13 +386,13 @@ extern void execCallbackProc(
 /*
  * Functions from file CONVERTERS.C
  */
-extern int convert(
+extern int wafeConvert(
 #if NeedFunctionPrototypes
      Widget, WidgetClass, char**, int*, ArgList*, int*, Widget
 #endif
 );
 
-extern Widget cvtName2Widget(
+extern Widget wafeCvtName2Widget(
 #if NeedFunctionPrototypes
      char *, Boolean, WidgetClass, char *
 #endif
@@ -389,30 +422,35 @@ extern void CvtStringToWidgetList(
 #endif
 );
 
-extern char * intsToTcl(
+extern char * wafeCvtIntsToTcl(
 #if NeedFunctionPrototypes
-     int, int *
+     char *, int, int *
 #endif
 );
 
-extern void estrcpy(
+extern void wafeEscapedStrcpy(
 #if NeedFunctionPrototypes
      String, String 
 #endif
 );
 
-extern char * widgetListToList(
+extern char * wafeCvtWidgetListToList(
 #if NeedFunctionPrototypes
-     int, WidgetList
+     char *, Cardinal, WidgetList
 #endif			 
 );
-#endif
 
+extern String wafeTopLevelWidget(
+#if NeedFunctionPrototypes
+     Widget
+#endif
+);
+#endif
 
 /*************************** externs from resources.c **************/
 
 #ifndef RESOURCES_C
-extern XrmQuark getQTypeOfAttribute(
+extern XrmQuark wafeGetQTypeOfAttribute(
 #if NeedFunctionPrototypes
      WidgetClass, Widget, XrmQuark
 #endif
@@ -421,7 +459,7 @@ extern XrmQuark getQTypeOfAttribute(
 
 /*************************** externs from createw.c **************/
 #ifndef CREATEW_C
-extern void createWidgetCommand(
+extern void wafeCreateWidgetCommand(
 #if NeedFunctionPrototypes
     char *, WidgetClass, Widget (*)(), Boolean
 #endif
@@ -430,7 +468,7 @@ extern void createWidgetCommand(
 
 
 #ifndef XT_C
-extern void xpmRegisterTypeConverter(
+extern void wafeRegisterXpmTypeConverter(
 #if NeedFunctionPrototypes
       char *, Boolean
 #endif
@@ -438,4 +476,3 @@ extern void xpmRegisterTypeConverter(
 #endif
 
 
-
